# Remaining issues or errors needing chasing

Listed here are known issues in the dataset which have yet to be solved. Some may never be recoverable so remain here for posterity.

[T] Tract data
[W] Tract Walker data
[POI] POI data
[P] FindPhoto data
[F] Finds data
[nk] Non-keepers find file

# May still be possible to resolve through careful checking

## Find data

- Generate by trying to find points for finds:

```
Polygon or line not found, skipping:  3836
     FindCode TractNo ItemCode                               CollectionYear
1096 ""       "3836"  "4727116A-D38C-42BB-A8F3-7E0E74249F2F" "2017"        
1097 ""       "3836"  "9B22129D-76EA-49A0-B3C6-2D048F9885FC" "2017"        
Polygon or line not found, skipping:  5389
     FindCode  TractNo ItemCode                               CollectionYear
2261 ""        "5389"  "F8D9BDDF-4C90-44C9-925F-C33E5971079F" "2017"        
2262 ""        "5389"  "CD2C579B-9727-4AE4-81F1-E12CD61BABBC" "2017"        
2263 "17PS315" "5389"  "595B8ADC-A6FF-4488-9DC8-A68348DEB445" "2017"        
Polygon or line not found, skipping:  5986
     FindCode  TractNo ItemCode CollectionYear
3084 "19PS226" "5986"  ""       "2019"        
Polygon or line not found, skipping:  5987
     FindCode  TractNo ItemCode CollectionYear
3085 "19PS401" "5987"  ""       "2019"        
3086 "19PS402" "5987"  ""       "2019"        
3087 "19PS403" "5987"  ""       "2019"        
```

## Error tracing: Incorrect tract numbering:

- 3731, 5286, 5389, 5450 [all from 2017 season]

These tracts are described as non-walkable. So these find descriptions must be typos in the find_data descriptions. The only way to correct them for sure is to compare to the original cards (where they are keepers), so something that needs checking in study season. Otherwise we are reduced to guessing based on nearby numbers.
3731, 5286*, 5389, 5450 [all from 2017 season]

[*5286 is not in tract database, even though it has spatial identity, but with multiple walkers, perhaps this is a walker not a non-walker?*]

- NOTE: these are currently excluded by the canonical script generator


- 5986, 5987 (19PS226, 19PS401-403)

These tracts DO NOT exist: I think these should be corrected to 5786 and 5787 respectively as typos in the find database (or miswritten labels in the field).


## Photo archive metadata

####### Photo tag checks #######

- **All years**: photographs are linked to the following non-existant TractNo or Tract Walker combinations. This list generated by check script in `survey-photo-archive/scripts`:-

```
======= The following Tract Tags are not found in canonical Tract data: ========
5136, 5286, 5825, 5579, 5620, 5987, 5980, 5986
======= The following Tract Walker combination of Tags are not found in canonical Tract Walker data: ========
3017-w006, 3075-w011, 3535-w022, 3727-w001, 3731-w022, 3943-w020, 3945-w020, 3947-w020, 3952-w020, 5283-w002, 5286-w019, 5336-w026, 5422-w021, 5424-w004, 5825-w026, 3555-w022, 3621-w001, 3670-w020, 3734-w021, 5288-w026, 5347-w016, 5458-w017, 5579-w016, 5636-w030, 3633-w028, 3942-w032, 5620-w028, 5664-w038, 5691-w002, 6118-w038, 5987-w038, 5980-w038, 5737-w001, 6169-w032, 3166-w038, 5631-w030, 5986-w038, 3900-w026, 3933-w001
```

=> Most of these need to be corrected by renaming of image files directly in the original survey-photo-archive, which may also involve re-interpretation of the labels shown in the photos.

# Probably unresolvable or not worth the effort

## Tract data

- **2015**: [TW] No ODK data for Tract 3493 -- oops, yes, that's because TW forgot to actually record it using the GPS after 2nd breakfast. It is a non-walked tract at the corner of the street and was full of modern rubbish dump. Probably not worth recording.

- **2017**: 5240, 5279 - these tract numbers were accidentally skipped in the field, so there is no associated data
