#!/usr/bin/Rscript --vanilla

#-------------------------------------------------------------------------------
# Aim: correcting the raw export from ODK
# Author (aut): Néhémie Strupler, Toby Wilkinson
# Maintainer (cre): Néhémie Strupler, Toby Wilkinson
# Last modified: 2019-09-18
# Licence: CC BY 4.0
#-------------------------------------------------------------------------------

# Load the data ------------------------------------------
## Define fixed variable

wd_survey <- c("../../survey-data/")
find_folder <- c("find-data/")
find_folder_2015 <- paste0(find_folder, "2015/")
find_folder_2017 <- paste0(find_folder, "2017/")
find_folder_2019 <- paste0(find_folder, "2019/")
find_folder_canonical <- paste0(find_folder, "canonical/")
find_keepers_2015  <- "finds.csv"
find_keepers_2017  <- "finds2017.csv"
find_keepers_2019  <- "finds2019.csv"
find_nonkeepers_2015  <- "finds-nonkeepers.csv"
find_nonkeepers_2017  <- "finds2017-nonkeepers.csv"
find_nonkeepers_2019  <- "finds2019-nonkeepers.csv"

### Note on keepers and non_keepers: due to restriction of collection/storage
### only the best preserved finds have been kept in the museum, the
### other pieces have been discarded near to their respective find spot.  The
### distinction between keepers and non keepers is therefore not relevant for the
### analysis, although non-keepers may be considered confirmatory items rather
### than raw evidence as they cannot be easily re-studied

### Load the walker data

## 2015
finds_keepers_2015 <-
  read.csv(paste0(wd_survey, find_folder_2015, find_keepers_2015),
                encoding = "UTF-8", na.strings = "", stringsAsFactors = FALSE)

finds_nonkeepers_2015 <-
  read.csv(paste0(wd_survey, find_folder_2015, find_nonkeepers_2015),
                encoding = "UTF-8", na.strings = "", stringsAsFactors = FALSE)

# Add collected year column to be able to group data later
finds_keepers_2015$CollectionYear <- "2015"
finds_nonkeepers_2015$CollectionYear <- "2015"

# Add keeper/non-keeper column to be able to sort later
finds_keepers_2015$NonKeeper <- ""
finds_nonkeepers_2015$NonKeeper <- "NK"

# Add ItemCode field
finds_keepers_2015$ItemCode <- paste0("PPS.",finds_keepers_2015$FindCode)
finds_nonkeepers_2015$ItemCode <- paste0("PPS.NK",finds_nonkeepers_2015$CollectionYear,
                                         ".",finds_nonkeepers_2015$Seq)

finds_data_2015 <- rbind(finds_keepers_2015, finds_nonkeepers_2015)
rm(finds_keepers_2015, finds_nonkeepers_2015)

## 2017

finds_keepers_2017 <-
  read.csv(paste0(wd_survey, find_folder_2017, find_keepers_2017),
                encoding = "UTF-8", na.strings = "", stringsAsFactors = FALSE)

finds_nonkeepers_2017 <-
  read.csv(paste0(wd_survey, find_folder_2017, find_nonkeepers_2017),
                encoding = "UTF-8", na.strings = "", stringsAsFactors = FALSE)

# Add collected year column to be able to group data later
finds_keepers_2017$CollectionYear <- "2017"
finds_nonkeepers_2017$CollectionYear <- "2017"

# Add keeper/non-keeper column to be able to sort later
finds_keepers_2017$NonKeeper <- ""
finds_nonkeepers_2017$NonKeeper <- "NK"

# Add ItemCode field
finds_keepers_2017$ItemCode <- paste0("PPS.",finds_keepers_2017$FindCode)
finds_nonkeepers_2017$ItemCode <- paste0("PPS.NK",finds_nonkeepers_2017$CollectionYear,
                                         ".",finds_nonkeepers_2017$Seq)

finds_data_2017 <- rbind(finds_keepers_2017, finds_nonkeepers_2017)
rm(finds_keepers_2017, finds_nonkeepers_2017)

## 2019

finds_keepers_2019 <-
  read.csv(paste0(wd_survey, find_folder_2019, find_keepers_2019),
                encoding = "UTF-8", na.strings = "", stringsAsFactors = FALSE)

finds_nonkeepers_2019 <-
  read.csv(paste0(wd_survey, find_folder_2019, find_nonkeepers_2019),
                encoding = "UTF-8", na.strings = "", stringsAsFactors = FALSE)

# Add collected year column to be able to group data later
finds_keepers_2019$CollectionYear <- "2019"
finds_nonkeepers_2019$CollectionYear <- "2019"

# Add keeper/non-keeper column to be able to sort later
finds_keepers_2019$NonKeeper <- ""
finds_nonkeepers_2019$NonKeeper <- "NK"

# Add ItemCode field
finds_keepers_2019$ItemCode <- paste0("PPS.",finds_keepers_2019$FindCode)
finds_nonkeepers_2019$ItemCode <- paste0("PPS.NK",finds_nonkeepers_2019$CollectionYear,
                                         ".",finds_nonkeepers_2019$Seq)

finds_data_2019 <- rbind(finds_keepers_2019, finds_nonkeepers_2019)
rm(finds_keepers_2019, finds_nonkeepers_2019)

# Add ALL years together

finds_data <- rbind(finds_data_2015, finds_data_2017, finds_data_2019)
rm(finds_data_2015, finds_data_2017, finds_data_2019)

finds_data$TractNo <- as.character(finds_data$TractNo)
# Remove NA
finds_data[is.na(finds_data)] <- ""

     ############################################################
     #############                                   ############
     ###########                                       ##########
     ########     S T A R T                              ########
     ####          P A N O R M O S #REMOTE#WEEK              ####
     ########                            2 0 2 0         ########
     ###########                                       ##########
     #############                                   ############
     ############################################################

    # Typos
     finds_data[
        !is.element(
          finds_data$Storage,
          c("Discarded", "FabricCollection", "Museum")),
          "Storage" ] <- ""

    # Exclude finds for which tract or line are missing
     # and are going to be checked in a possible study
     # season.

##     finds_data <-
##       finds_data[
##        !is.element(
##          finds_data$TractNo,
##          c(  "3852",
##              "3836", "3919", "3922", "3923", "3924",
##              "5986", "5987", "6008", "6010", "6014",
##              "3622", "3625", "3628", "3639", "3671",
##              "3672", "3719", "3731", "3777", "3836",
##              "3859", "3919", "3922", "3923", "3924",
##              "3925", "5184", "5250", "5286", "5297",
##              "5356", "5389", "5450", "5519", "5533",
##              "5534", "5675", "5686", "5756", "5986",
##              "5987", "6004", "6005", "6008", "6010",
##              "6014", "6169", "6172"
##)),
##           ]

     ############################################################
     #############                                   ############
     ###########                                       ##########
     ########     E N D                                  ########
     ####          P A N O R M O S #REMOTE#WEEK              ####
     ########                            2 0 2 0         ########
     ###########                                       ##########
     #############                                   ############
     ############################################################

# Order finds data by ItemCode
finds_data <- finds_data[order(finds_data$CollectionYear, 
                               finds_data$NonKeeper,
                               finds_data$Seq,
                               na.last = TRUE), ]
#finds_data <- finds_data[order(finds_data$TractNo, finds_data$POINo,
#                               finds_data$FindCode, na.last = TRUE), ]
rownames(finds_data) <- 1:nrow(finds_data)

# Drop unwanted fields (Seq) and put ItemCode in column 1
finds_data <- finds_data[,c("ItemCode",
                            names(finds_data)[!names(finds_data) %in% c("ItemCode","Seq","NonKeeper")])]

# Compare data with canonical
finds_data_test <- finds_data
finds_data_test[] <- apply(finds_data_test, 2, as.character)

# Read canonical data and make them similar to finds data
finds_data_initial_path <- paste(wd_survey,find_folder_canonical,
                                 "finds_data.csv", sep = "")
if (file.exists(finds_data_initial_path)) {
  finds_data_initial <- read.csv(finds_data_initial_path,
                                 stringsAsFactors = FALSE)
  finds_data_initial[is.na(finds_data_initial)] <- ""
  finds_data_initial[] <- apply(finds_data_initial, 2, as.character)

  # Test for similarity
  test_diff <- identical(finds_data_test, finds_data_initial)
  rm(finds_data_test, finds_data_initial)

  # Exporting data if needed and user say Y
  if (test_diff == FALSE) {
    while (test_diff != "Y" | test_diff != "N") {
      cat("\n \n The 'finds_data' have been changed and")
      cat("\n the canonical version will be updated.")
      cat("\n Do you agree [Y/N]? ")
      cat("\n (use a capital letter)   :")
      test_diff  <- readChar("stdin", 1)
      if (test_diff == "Y") {
        write.csv(finds_data,
                  file = paste(wd_survey,find_folder_canonical,
                               "finds_data.csv", sep = ""),
                  row.names = FALSE)
        cat("\n Canonical data have been overwritten\n \n")
        break}  # breaks when hit enter
      if (test_diff == "N") {
        cat("\n Canonical data have NOT been overwritten\n \n")
        break}  # breaks when hit enter
}
  } else
    cat("\n finds_data are already identical to canonical data \n \n ")
}
if (!file.exists(finds_data_initial_path)) {
    write.csv(finds_data,
              file = paste(wd_survey,find_folder_canonical,
                           "finds_data.csv", sep = ""),
              row.names = FALSE)
  cat("\n a file finds_data.csv has been added in the folder canonical \n \n ")
}
