#!/usr/bin/Rscript --vanilla

#-------------------------------------------------------------------------------
# Aim: correcting the raw export from ODK
# Author (aut): Néhémie Strupler, Toby Wilkinson
# Maintainer (cre): Néhémie Strupler, Toby Wilkinson
# Last modified: 2019-09-18
# Licence: CC BY-SA 4.0
#-------------------------------------------------------------------------------

# Load the data
## Define fixed variable

wd_survey <- c("../../survey-data/")
poi_folder <- c("poi-data/")
poi_folder_odk <- paste0(poi_folder, "export_odk/")
poi_folder_canonical <- paste0(poi_folder, "canonical/")
poi_r1  <- "POI_r1/POI.csv"
poi_r2  <- "POI_r2/POI.csv"
poi_r3  <- "POI_r3/POI.csv"
poi_r4  <- "POI_r4/POI_r4.csv"
poi_r6  <- "POI_r6/POI_r6.csv"
poi_r7  <- "POI_r7/POI_r7.csv"
poi_canonical <- "POI_data.csv"

wd_survey_spatial <- c("../../survey-spatial/")
poi_spatial <- c("pois/panormos_poi_coordinates.csv")

description_poi_data_path <- paste0(wd_survey, poi_folder,
                                     "description_canonical_poi-data.csv")

### Load the poi data
poi_data_r1 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r1), encoding = "UTF-8")
poi_data_r2 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r2), encoding = "UTF-8")
poi_data_r3 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r3), encoding = "UTF-8")
poi_data_r4 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r4), encoding = "UTF-8")
poi_data_r6 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r6), encoding = "UTF-8")
poi_data_r7 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r7), encoding = "UTF-8")

poi_data_r1$revision <- "POI_r1"
poi_data_r2$revision <- "POI_r2"
poi_data_r3$revision <- "POI_r3"
poi_data_r4$revision <- "POI_r4"
poi_data_r6$revision <- "POI_r6"
poi_data_r7$revision <- "POI_r7"

description_poi_data <-
  read.csv(description_poi_data_path,
           encoding = "UTF-8", na.strings = c(NA,""))

### ABOUT R1 to R4: After the first days of working with a first version of the
### ODK from (r1) some modifications have been made to improve it.

# Align r1 with r3, rename or construct missing columns
colnames(poi_data_r1)[which(names(poi_data_r1) == "SET.OF.photos")] <- "SET.OF.basic_data.photos"
colnames(poi_data_r1)[which(names(poi_data_r1) == "environment.human_disturb")] <- "environment.environment_notes.human_disturb"
colnames(poi_data_r1)[which(names(poi_data_r1) == "environment.sea_shells")] <- "environment.environment_notes.sea_shells"
colnames(poi_data_r1)[which(names(poi_data_r1) == "environment.fossils")] <- "environment.environment_notes.fossils"
poi_data_r1$follow_up_data.pot_intensive <- NA
poi_data_r1$poi_summary.poi_category <- NA
poi_data_r1$refer_tract_env_data <- NA
poi_data_r1 <- subset(poi_data_r1, select = -dimensions.gis_polygon)

# Align r2 with r3
colnames(poi_data_r2)[which(names(poi_data_r2) == "SET.OF.photos")] <- "SET.OF.basic_data.photos"
poi_data_r2 <- subset(poi_data_r2, select = -dimensions.gis_polygon)

poi_data <- rbind(poi_data_r1, poi_data_r2)
poi_data <- rbind(poi_data, poi_data_r3)

# Construct columns not available in r1, 2,3
poi_data$start <- NA
poi_data$end <- NA

poi_data <- rbind(poi_data, poi_data_r4)

# Construct columns not available in r4
poi_data$basic_data.illegal_excavation <- NA
poi_data$poi_summary.poi_excavation_subtype <- NA
poi_data$poi_summary.poi_excavation_subtype_other <- NA

# Add r6 (2017)
poi_data <- rbind(poi_data, poi_data_r6)

# Add r7 (2019)
poi_data <- rbind(poi_data, poi_data_r7)

rm(poi_data_r1, poi_data_r2, poi_data_r3, poi_data_r4, poi_data_r6, poi_data_r7)

# Compare poi data with canonical: need order and charcters
poi_data <- poi_data[order(poi_data$basic_data.poi_no), ]
rownames(poi_data) <- 1:nrow(poi_data)

## Change variable names with file description
poi_data <- subset(poi_data,
                      select = as.character(description_poi_data$ODKExportName))
colnames(poi_data) <- description_poi_data$Variable
poi_data <- poi_data[!is.na(colnames(poi_data))]
poi_data[is.na(poi_data)] <- ""

## Standardise dates using lubridate
#desired format: "%d-%b-%Y %H:%M:%S"
library(lubridate)
poi_data$FormToday <- format(lubridate::parse_date_time(poi_data$FormToday, orders = c("d-m-y", "m d,y")),"%d-%b-%Y")
poi_data$FormSubmissionDate <- format(lubridate::parse_date_time(poi_data$FormSubmissionDate, orders = c("d-m-y H:M:S", "m d,y I:M:S p")),"%d-%b-%Y %H:%M:%S")

##################################################################
###################### CORRECTIONS TO DATA
##################################################################

######################  2017

# Renumber duplicated POIs using UUIDs

# Duplicate POI=2014s, change one (Wall) to empty sequence
poi_data$POINo[poi_data$ODK_KEY=="uuid:6c0e5550-b33a-44a0-aede-eb20c0f667b9"] <- 1501

# Duplicate POI=2015s, change one (Milestone? Column?) to empty sequence
poi_data$POINo[poi_data$ODK_KEY=="uuid:4c5e9630-4ac0-455a-bfbc-1bc19992fbde"] <- 1502

# Duplicate POI=2016s, change one (View of sulu valley) to empty sequence
poi_data$POINo[poi_data$ODK_KEY=="uuid:dc7aab92-547b-4361-886a-147636893d6c"] <- 1503

# Duplicate POI=2020, change one
poi_data$POINo[poi_data$ODK_KEY=="uuid:a0939300-83f3-4b34-86f4-644a33aaa8d2"] <- 2025

# Duplicate POI=4023, change one
poi_data$POINo[poi_data$ODK_KEY=="uuid:b6d4b9fc-d1cf-4ba2-b03e-589af89bc61b"] <- 4034

# Temporary no accidentally submitted POI=9999, change to within sequence
poi_data$POINo[poi_data$ODK_KEY=="uuid:3dd2c47b-8d21-4855-a061-5d719b13ffa5"] <- 2017

######################  2019

poi_data$POINo[poi_data$ODK_KEY=="PAD13CBKJU2B2VHFOCUDS3C52"] <- 2027

poi_data$POINo[poi_data$ODK_KEY=="A75W7Z8HC8V1BNWGTGV70XAML"] <- 2049

##################################################################
###################### FINAL CLEANING
##################################################################

# Check for duplicated POI Nos - must reject if any overlaps

if (anyDuplicated(poi_data$POINo)>0) {
  poi_test <- subset(poi_data, select=c("POINo", "TypeGeneral", "Interpretation", "ODK_KEY"))
  poi_test <- poi_test[match(poi_test$POINo,poi_test[duplicated(poi_test$POINo),1]) > 0,]
  poi_test <- poi_test[!is.na(poi_test$ODK_KEY),]
  cat("\n The following POI nos are duplicated. These errors need to be fixed to avoid problems later \n")
  print(poi_test)
  stop("Duplicated POI numbers found. Cannot create canonical version")
}

#Resort
# Compare poi data with canonical: need order and charcters
poi_data <- poi_data[order(poi_data$POINo), ]
rownames(poi_data) <- 1:nrow(poi_data)

#### Make a copy of POI_data
poi_data_test <- poi_data

for (i in 1:ncol(poi_data_test)) {
  if (is.factor(poi_data_test[,i]) == TRUE) {
    poi_data_test[,i] <- as.character(poi_data_test[,i])
  } else
  if (is.integer(poi_data_test[,i]) == TRUE) {
    poi_data_test[,i] <- as.numeric(poi_data_test[,i])
  }
}

# Read canonical data and make them similar to poi data
poi_data_initial_path <- paste0(wd_survey, poi_folder_canonical,poi_canonical)
if (file.exists(poi_data_initial_path)) {
  poi_data_initial <- read.csv(poi_data_initial_path, stringsAsFactors = FALSE, check.names = FALSE)
  for (i in 1:ncol(poi_data_initial)) {
    if (is.integer(poi_data_initial[,i]) == TRUE) {
      poi_data_initial[,i] <- as.numeric(poi_data_initial[,i])
    }
  }
  poi_data_initial[is.na(poi_data_initial)] <- ""

  test_diff <- identical(poi_data_test, poi_data_initial)
  rm(poi_data_test, poi_data_initial)



  # Exporting data if needed and user say Y
  if (test_diff == FALSE) {
    while (test_diff != "Y" | test_diff != "N") {
      cat("\n \n The 'poi_data' have been changed and")
      cat("\n the canonical version will be updated.")
      cat("\n Do you agree [Y/N]? ")
      cat("\n (use a capital letter)   :")
      test_diff  <- readChar("stdin", 1)
      if (test_diff == "Y") {
        write.csv(poi_data,
                  file = paste(wd_survey,poi_folder_canonical,
                               poi_canonical, sep = ""),
                  row.names = FALSE)
        cat("\n Canonical data have been overwritten\n \n")
        break}  # breaks when hit enter
      if (test_diff == "N") {
        cat("\n Canonical data have NOT been overwritten\n \n")
        break}  # breaks when hit enter
    }
  } else
    cat("\n poi_data are already identical to canonical data \n \n ")
}
if (!file.exists(poi_data_initial_path)) {
  write.csv(poi_data,
          file = paste(wd_survey,poi_folder_canonical,
                       poi_canonical, sep = ""),
          row.names = FALSE)
  cat("\n a file poi_data.csv has been added in the folder canonical \n \n ")
}
