#!/usr/bin/Rscript --vanilla

#-------------------------------------------------------------------------------
# Aim: correcting the raw export from ODK for POI photos
# Author (aut): Néhémie Strupler / adapted by Toby C. Wilkinson
# Maintainer (cre): Néhémie Strupler, Toby Wilkinson
# Last modified: 2019-09-18
# Licence: CC BY-SA 4.0
#-------------------------------------------------------------------------------

# Load the data
## Define fixed variable

wd_survey <- c("../../survey-data/")
poi_folder <- c("poi-data/")
poi_folder_odk <- paste0(poi_folder, "export_odk/")
poi_folder_canonical <- paste0(poi_folder, "canonical/")
poi_r1  <- "POI_r1/POI_photos.csv"
poi_r2  <- "POI_r2/POI_photos.csv"
poi_r3  <- "POI_r3/POI_basic_data_photos.csv"
poi_r4  <- "POI_r4/POI_r4_basic_data_photos.csv"
poi_r6  <- "POI_r6/POI_r6_basic_data_photos.csv"
poi_r7  <- "POI_r7/POI_r7-photos.csv"
poi_canonical <- "POI_data.csv"
poi_canonical_photo <- "POI_photo_data.csv"

description_poi_photo_data_path <- paste0(wd_survey, poi_folder,
                                     "description_canonical_poi-photo-data.csv")

### Load the poi data
poi_photo_data_r1 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r1), encoding = "UTF-8")
poi_photo_data_r2 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r2), encoding = "UTF-8")
poi_photo_data_r3 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r3), encoding = "UTF-8")
poi_photo_data_r4 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r4), encoding = "UTF-8")
poi_photo_data_r6 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r6), encoding = "UTF-8")
poi_photo_data_r7 <-
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r7), encoding = "UTF-8")

poi_data_canonical <-
  read.csv(paste(wd_survey, poi_folder_canonical, poi_canonical, sep = ""),
           encoding = "UTF-8")

description_poi_photo_data <-
  read.csv(description_poi_photo_data_path,
           encoding = "UTF-8", na.strings = c(NA,""))

poi_photo_data_r1$revision <- "POI_r1"
poi_photo_data_r2$revision <- "POI_r2"
poi_photo_data_r3$revision <- "POI_r3"
poi_photo_data_r4$revision <- "POI_r4"
poi_photo_data_r6$revision <- "POI_r6"
poi_photo_data_r7$revision <- "POI_r7"

# r1 and r2 do not have caption field
poi_photo_data <- rbind(poi_photo_data_r1, poi_photo_data_r2)
poi_photo_data$caption <- NA

#r6 and r7 for some reasons misses the media/ listing from the export of photo filename
poi_photo_data_r6$poi_photo <- paste0("media/",poi_photo_data_r6$poi_photo)
poi_photo_data_r7$poi_photo <- paste0("media/",poi_photo_data_r7$poi_photo)

poi_photo_data <- rbind(poi_photo_data, poi_photo_data_r3)
poi_photo_data <- rbind(poi_photo_data, poi_photo_data_r4)
poi_photo_data <- rbind(poi_photo_data, poi_photo_data_r6)
poi_photo_data <- rbind(poi_photo_data, poi_photo_data_r7)

rm(poi_photo_data_r1, poi_photo_data_r2, poi_photo_data_r3, poi_photo_data_r4,
   poi_photo_data_r6, poi_photo_data_r7)

### ABOUT R1 to R4: After the first days of working with a first version of the
### ODK from (r1) some modifications have been made to improve it. See other POI
### cleaning script for details

### Remove photos without poi_photo i.e. FileName (seeing as how they don't
### actually relate to anything)

cat("\n Any entries with no poi_photo value will be listed here \n \n ")

poi_photo_data[is.na(poi_photo_data$poi_photo),]
poi_photo_data[poi_photo_data$poi_photo == "",]

# remove these problems from the data
poi_photo_data <- poi_photo_data[!is.na(poi_photo_data$poi_photo),]
poi_photo_data <- poi_photo_data[!poi_photo_data$poi_photo == "",]

### Merge or join poi_data_canonical and poi_photo_data to find POINo

# Just extract the wanted columns from canonical (i.e. cleaned and corrected) version
poi_data_canonical <- subset(poi_data_canonical, select=c("POINo", "ODK_KEY", "FormToday"))

# combine poi_photo_data with poi_data_canonical
poi_photo_data <- merge(x = poi_photo_data, y = poi_data_canonical,
                          by.x = "PARENT_KEY", by.y = "ODK_KEY", all.x = TRUE)

### Test for missing POINos (i.e. non matching IDs); list them and print them

cat("\n Any photos which cannot be linked with POINo will be listed here \n \n ")
poi_photo_data[is.na(poi_photo_data$POINo),]
# Remove photos without identifiable link to POINo
poi_photo_data <- poi_photo_data[!is.na(poi_photo_data$POINo),]

### Create a longer filename so that image files can be identified in photo-archive
# tract_photo and revision should be merged so that filename reflects source and photo archive
poi_photo_data$ShortFileName <- poi_photo_data$poi_photo
poi_photo_data$poi_photo <- paste("",format(as.Date(poi_photo_data$FormToday, format="%d-%b-%Y"),"%Y"),"Core","Field","POI",poi_photo_data$revision,poi_photo_data$poi_photo,sep="/")

### All tracts with id nos. under 1000 should be removed from analysis

cat("\n Excluded because POINo< 1000 i.e. these are tests and not real survey data \n \n ")
poi_photo_data[poi_photo_data$POINo < 1000]
#Remove them
poi_photo_data <- poi_photo_data[poi_photo_data$POINo > 999,]

### Order by POINo
poi_photo_data <- poi_photo_data[order(poi_photo_data$POINo), ]
rownames(poi_photo_data) <- 1:nrow(poi_photo_data)

## Change variable names with file description
poi_photo_data <- subset(poi_photo_data,
                      select = as.character(description_poi_photo_data$ODKExportName))
colnames(poi_photo_data) <- description_poi_photo_data$Variable
poi_photo_data <- poi_photo_data[!is.na(colnames(poi_photo_data))]
poi_photo_data[is.na(poi_photo_data)] <- ""

# Remove unwanted columns
poi_photo_data$`_NOT_EXPORTED_TO_CANONICAL_` <- NULL

#### Make a copy of POI_data
poi_photo_data_test <- poi_photo_data

for (i in 1:ncol(poi_photo_data_test)) {
  if (is.factor(poi_photo_data_test[,i]) == TRUE) {
    poi_photo_data_test[,i] <- as.character(poi_photo_data_test[,i])
  } else
  if (is.integer(poi_photo_data_test[,i]) == TRUE) {
    poi_photo_data_test[,i] <- as.numeric(poi_photo_data_test[,i])
  }
}

# Read canonical data and make them similar to poi data
poi_photo_data_initial_path <- paste0(wd_survey, poi_folder_canonical, poi_canonical_photo)
if (file.exists(poi_photo_data_initial_path)) {
  poi_photo_data_initial <- read.csv(poi_photo_data_initial_path, stringsAsFactors = FALSE)
  for (i in 1:ncol(poi_photo_data_initial)) {
    if (is.integer(poi_photo_data_initial[,i]) == TRUE) {
      poi_photo_data_initial[,i] <- as.numeric(poi_photo_data_initial[,i])
    }
  }
  poi_photo_data_initial[is.na(poi_photo_data_initial)] <- ""

  test_diff <- identical(poi_photo_data_test, poi_photo_data_initial)
  rm(poi_photo_data_test, poi_photo_data_initial)



  # Exporting data if needed and user say Y
  if (test_diff == FALSE) {
    while (test_diff != "Y" | test_diff != "N") {
      cat("\n \n The 'poi_photo_data' have been changed and")
      cat("\n the canonical version will be updated.")
      cat("\n Do you agree [Y/N]? ")
      cat("\n (use a capital letter)   :")
      test_diff  <- readChar("stdin", 1)
      if (test_diff == "Y") {
        write.csv(poi_photo_data,
                  file = paste(wd_survey,poi_folder_canonical,
                               poi_canonical_photo, sep = ""),
                  row.names = FALSE)
        cat("\n Canonical data have been overwritten\n \n")
        break}  # breaks when hit enter
      if (test_diff == "N") {
        cat("\n Canonical data have NOT been overwritten\n \n")
        break}  # breaks when hit enter
    }
  } else
    cat("\n poi_photo_data are already identical to canonical data \n \n ")
}
if (!file.exists(poi_photo_data_initial_path)) {
  write.csv(poi_photo_data,
          file = paste(wd_survey,poi_folder_canonical,
                       poi_canonical_photo, sep = ""),
          row.names = FALSE)
  cat("\n a file poi_photo_data.csv has been added in the folder canonical \n \n ")
}
