#!/usr/bin/Rscript --vanilla

#--------------------------------------------------------------------------------
# Aim: correcting the raw export from ODK
# Author (aut): Néhémie Strupler
# Maintainer (cre): Néhémie Strupler
# Last modified: 2017-09-10
# Licence: CC BY 4.0
#--------------------------------------------------------------------------------

# Load the data ------------------------------------------
## Define fixed variable

wd_survey <- c("../../survey-data/")
tract_folder <- c("tract-data/")
tract_folder_odk <- paste(tract_folder, "export_odk/", sep = "")
tract_folder_canonical <- paste(tract_folder, "canonical/", sep = "")
tract_r2  <- "Tract_r2/Tract.csv"
tract_r4  <- "Tract_r4/Tract_r4.csv"
tract_r7  <- "Tract_r7/Tract_r7.csv"
tract_r10  <- "Tract_r10/Tract_r10.csv"
tract_r11  <- "Tract_r11/Tract_r11.csv"
description_tract_data_path <- paste(wd_survey, tract_folder,
                                     "description_canonical_tract-data.csv", sep = "")
### Load the tract data
tract_data_r2 <-
  read.csv(paste0(wd_survey, tract_folder_odk, tract_r2),
          encoding = "UTF-8")
tract_data_r2$revision <- "tract_data_r2"

tract_data_r4 <-
  read.csv(paste0(wd_survey, tract_folder_odk, tract_r4),
              encoding = "UTF-8")
tract_data_r4$revision <- "tract_data_r4"

tract_data_r7 <-
  read.csv(paste0(wd_survey, tract_folder_odk, tract_r7),
              encoding = "UTF-8")
tract_data_r7$revision <- "tract_data_r7"

tract_data_r10 <-
  read.csv(paste0(wd_survey, tract_folder_odk, tract_r10),
              encoding = "UTF-8")
tract_data_r10$revision <- "tract_data_r10"

tract_data_r11 <-
  read.csv(paste0(wd_survey, tract_folder_odk, tract_r11),
              encoding = "UTF-8")
tract_data_r11$revision <- "tract_data_r11"

description_tract_data <-
  read.csv(description_tract_data_path,
           encoding = "UTF-8", na.strings = c(NA,""))


# Add colnames to r2 to have the same format as r4
tract_data_r2$start <- NA
tract_data_r2$end <- NA
tract_data_r2$walkable_tract_data.soilrock_detail.freshly_ploughed <- NA
tract_data_r2 <- subset(tract_data_r2, select = -gis_polygon)
tract_data_r2 <- tract_data_r2[, colnames(tract_data_r4)]

tract_data <- rbind(tract_data_r2, tract_data_r4)
rm(tract_data_r2, tract_data_r4)

tract_data_r7 <- rbind(tract_data_r7, tract_data_r10, tract_data_r11)
tract_data_r7$walkable_tract_data.find_condition <- NA
tract_data_r7$walkable_tract_data.find_fragmentsize <- NA
tract_data$walkable_tract_data.environment_detail.surface_disturb_type <- NA
tract_data$walkable_tract_data.environment_detail.surface_disturb_type_other <- NA
correct_time_format <- function(var){
  format(
  strptime(var, format = "%b %e, %Y %I:%M:%S %p"),
  "%d-%b-%Y %H:%M:%S"
  )
}
tract_data_r7[c(1,3:4)] <- lapply(tract_data_r7[c(1,3:4)], correct_time_format)
correct_date_format <- function(var){
  format(
  strptime(var, format = "%b %e, %Y"),
  "%d-%b-%Y"
  )
}
tract_data_r7[2] <- lapply(tract_data_r7[2], correct_date_format)

# strptime("september", format = "%b")

tract_data <- rbind(tract_data, tract_data_r7)
rm(tract_data_r7)
### ABOUT R2 AND R4: After the first days of working with a first
### version of the ODK form (r2), some modifications have been made
### to improve it. Even if the name of the walker data file site was
### modified, the changes didn't affect the newer version (r4) of
### walker_data.
###
### ABOUT R7: Modification for 2017 that affects tract and walkers data

# Tract data corrections ------------------------------

# ODK Briefcase seems to export exact duplicates for many lines;
  # these need to be checked for and removed in canonical version.
     tract_data <- unique(tract_data)

  #Tr 3012 has been removed from GIS: it was later walked as 3500)
     tract_data <- tract_data[tract_data$basic_data.tract_no != 3012,]

   #Tr 3260 has been removed from GIS: it was later rewalked as 3474)
     tract_data <- tract_data[tract_data$basic_data.tract_no != 3260,]

  # Duplicate entries for 3524, one walked, one non-walkable.
  # The non-walkable has been labelled 5123 in GIS
  tract_data[tract_data$basic_data.tract_no == 3524 &
             tract_data$basic_data.tract_nw == "nw",
             "basic_data.tract_no"] <- 5123

  #  as they are training tracts. (After the correction that Tr 3481
  #  has been incorrectly labelled 481)
  tract_data[tract_data$basic_data.tract_no == 481 ,
             "basic_data.tract_no"] <- 3481

  # [TW] Tr 3008 is duplicated with identical data but different keys
  #  (presumably it has somehow been submitted twice). We should ignore
  #  the first entry (uuid: ...c2c3)
  tract_data <-
    tract_data[tract_data$KEY != "uuid:32a318f3-340e-4c51-ace0-69799568c2c3",]


  ## Tr 3117 has been mistakenly entered as 3116 (i.e. there are two entries for
  ## 3116) The later 3116 should be renamed 3117
  tract_data[tract_data$basic_data.tract_no == 3116 &
                 tract_data$KEY == "uuid:628ffc43-cb0d-4a6e-87c3-a95dcc43b317",
                 "basic_data.tract_no"] <- 3117

  ## Tr 3176 has been mistakenly entered as 3175 (i.e. there are two entries for
  ## 3175) the later 3175 should be 3176
     tract_data[tract_data$basic_data.tract_no == 3175 &
                 tract_data$KEY == "uuid:84d96bae-43d5-4be9-b135-fb2ac2ffb2e5",
                 "basic_data.tract_no"] <- 3176

  ##  [T] Tr 3136 and 3137, direction should be 0 deg. not 180 deg.
     tract_data[tract_data$basic_data.tract_no %in% c(3136,3137),
                  "walkable_tract_data.walking_direction"] <- "0"

  # - [T] Tr 0 --> should be 5067
     tract_data[tract_data$basic_data.tract_no == 0 &
                 tract_data$KEY == "uuid:1b8b90b7-a937-4787-add5-8acb9a142801",
                 "basic_data.tract_no"] <- 5067

  # - [TW] Tr 32303 should be 3203
     tract_data[tract_data$basic_data.tract_no == 32303 &
                 tract_data$KEY == "uuid:14e7c6a5-577c-4ec2-982b-e300cc597967",
                 "basic_data.tract_no"] <- 3203

  # [TW] 3298 has been incorrectly entered as 3290
	# - Tr 3298 has a uuid: ...bfdc
     tract_data[tract_data$basic_data.tract_no == 3290 &
                 tract_data$KEY == "uuid:b01d7ec2-d6ed-4719-9b61-c92532e4bfdc",
                 "basic_data.tract_no"] <- 3298

	# [TW] Tr 5090 seems to have been entered as 5060
	# (hence there are duplicate 5060s)
	 # - Tr 5090 (uuid: ...b021)
     tract_data[tract_data$basic_data.tract_no == 5060 &
                 tract_data$KEY == "uuid:4066628f-9abe-4794-92d4-d91a8101b021",
                 "basic_data.tract_no"] <- 5090


  # - [TW] Tr 3355 has been entered as 3354
  # (hence there are duplicate 3354s)
  #  Tr 3355 has uuid of: ...16e5
     tract_data[tract_data$basic_data.tract_no == 3354 &
                 tract_data$KEY == "uuid:b5f75d6b-76ec-4524-9e24-450fd51316e5",
                 "basic_data.tract_no"] <- 3355

  # [T] Tr 3359, direction should be 270 deg, not 0
     tract_data[tract_data$basic_data.tract_no %in% c(3359),
                  "walkable_tract_data.walking_direction"] <- "270"

  # [TW] Tr 33666 should be 3366
     tract_data[tract_data$basic_data.tract_no == 33666 &
                 tract_data$KEY == "uuid:6eb1c4c1-54e4-4554-8b3f-ba7a92842f61",
                 "basic_data.tract_no"] <- 3366

  # - [TW] Tr 3411 has been labelled 3410 (i.e. there are duplicate 3410)
     tract_data[tract_data$basic_data.tract_no == 3410 &
                 tract_data$KEY == "uuid:3e2678a1-7b20-45c4-af1f-20c25d135c9f",
                 "basic_data.tract_no"] <- 3411

  # - [TW] Tr 3466 has been labelled 3465 (i.e. there are duplicate 3465)
	# Tr 3466 has uuid of .uuid:df9cca40-bf2a-48f0-8395-a6ac60c43179
     tract_data[tract_data$basic_data.tract_no == 3465 &
                 tract_data$KEY == "uuid:df9cca40-bf2a-48f0-8395-a6ac60c43179",
                 "basic_data.tract_no"] <- 3466

  ## Tr 3483 has been incorrectly labelled 3477 (hence there are duplicate 3477)
  #- Tr 3483 is a 4 walker and has a uuid:0056af41-ac04-4d6e-8d25-37081a32ca9e
     tract_data[tract_data$basic_data.tract_no == 3477 &
                 tract_data$KEY == "uuid:0056af41-ac04-4d6e-8d25-37081a32ca9e",
                 "basic_data.tract_no"] <- 3483

  ## [T] Duplicate entries for 3524, one walked, one non-walkable.
	# Tr 5123 should be the new number for the non-walkable (uuid: ...0067)
     tract_data[tract_data$basic_data.tract_no == 3524 &
                 tract_data$KEY == "uuid:e722e2ed-842b-492a-bba2-b1350ed00067",
                 "basic_data.tract_no"] <- 5123

  ## - [TW] Tr 5340 should be labelled Tr 3540
     tract_data[tract_data$basic_data.tract_no == 5340 &
                 tract_data$KEY == "uuid:ba2e5229-6e47-4afe-8ac3-1be06b3421ef",
                 "basic_data.tract_no"] <- 3540

  ## - [TW] Tr 3507 has been incorrectly labelled 5507
     tract_data[tract_data$basic_data.tract_no == 5507 &
                 tract_data$KEY == "uuid:93b66cc6-9224-4148-b506-ff87fe869798",
                 "basic_data.tract_no"] <- 3507


  ## - [TW] ODK data for Tracts 3503, 3504, 3505 or 3506 has been wrongly
     ## labelled 4503, 4504, 4505, 4506
     tract_data[tract_data$basic_data.tract_no == 4503 &
                 tract_data$KEY == "uuid:91475bb0-032f-47c1-879f-d5ac475e6808",
                 "basic_data.tract_no"] <- 3503
     tract_data[tract_data$basic_data.tract_no == 4504 &
                 tract_data$KEY == "uuid:1214bae8-033e-4774-bdd1-4c10aee827fc",
                 "basic_data.tract_no"] <- 3504
     tract_data[tract_data$basic_data.tract_no == 4505 &
                 tract_data$KEY == "uuid:16fae20b-9b60-46c5-802b-d3f979f53c09",
                 "basic_data.tract_no"] <- 3505
     tract_data[tract_data$basic_data.tract_no == 4506 &
                 tract_data$KEY == "uuid:68ade9a8-8cf7-436f-9211-b5d6204c1566",
                 "basic_data.tract_no"] <- 3506

     # [T & W] Wrong number from TEAM A. Rename 5420 -> 3816,
     # 5421 -> 3817, 5422 -> 3818, 5423 -> 3819, 5424 -> 3820, 5425 -> 3821
     tract_data[tract_data$basic_data.tract_no == 5420 &
                 tract_data$KEY == "uuid:ba74b8c6-fce2-45da-847c-5cb140a20b79",
                 "basic_data.tract_no"] <- 3816
     tract_data[tract_data$basic_data.tract_no == 5421 &
                 tract_data$KEY == "uuid:a7f1e2bd-2173-427f-8235-5af06ffcb9ff",
                 "basic_data.tract_no"] <- 3817
     tract_data[tract_data$basic_data.tract_no == 3422 & # Typo instead 5422
                 tract_data$KEY == "uuid:523f0c64-8365-4465-b62b-802bb5c159b3",
                 "basic_data.tract_no"] <- 3818
     tract_data[tract_data$basic_data.tract_no == 5426 &
                 tract_data$KEY == "uuid:e4681a8d-fd4e-41cd-8d5f-24b4f939d909",
                 "basic_data.tract_no"] <- 3819
     tract_data[tract_data$basic_data.tract_no == 5424 &
                 tract_data$KEY == "uuid:a499b55f-098f-46d0-9500-7b93c27eeb15",
                 "basic_data.tract_no"] <- 3820
     tract_data[tract_data$basic_data.tract_no == 5425 &
                 tract_data$KEY == "uuid:f6ce6c8a-abb8-4d8d-bc8c-ee97ba498cc1",
                 "basic_data.tract_no"] <- 3821

  # [T & W] TEAM A: Typo in TractNo (two times 3614 and no 3615).
  # Change the second 3614 in 3615
     tract_data[tract_data$basic_data.tract_no == 3614 &
                 tract_data$KEY == "uuid:66832a54-f684-4b5d-8fd0-2002af24f95c",
                 "basic_data.tract_no"] <- 3615

  # [T & W] TEAM A: Typo in TractNo 6672.
  # Change 6672 in 3672
     tract_data[tract_data$basic_data.tract_no == 6672 &
                 tract_data$KEY ==  "uuid:64505d19-58de-4ef2-a6eb-aaac8d55d583",
                 "basic_data.tract_no"] <- 3672

  #  [T & W] TEAM A: Typo in TractNo (two times 3749 and no 3748).
  #  Change the second 3749 in 3748
     tract_data[tract_data$basic_data.tract_no == 3749 &
                 tract_data$KEY == "uuid:430dd6dd-00d3-4891-913c-4d32fdb6f5f4",
                 "basic_data.tract_no"] <- 3748

  #  [T & W] first 3799
  #  [KEY="uuid:ee233f98-bce2-4dc3-bfb3-70a222f2cf1b"] =>
  #  TractNo should be 3798
     tract_data[tract_data$KEY == "uuid:ee233f98-bce2-4dc3-bfb3-70a222f2cf1b",
                 "basic_data.tract_no"] <- 3798

  #  [T & W] TEAM A: Typo in TractNo (two times 3818 and no 3815).
  #  Change the first 3818 in 3815
     tract_data[tract_data$basic_data.tract_no == 3818 &
                 tract_data$KEY == "uuid:f99e059c-ab5d-4abf-a58e-bebbfe7e1cf4",
                 "basic_data.tract_no"] <- 3815

  # [T] TractNo Tr5288 with
  # uuid:baf35399-aa85-49d6-94fd-a980dd863ca9:
  # EXCLUDE this entry from canonical This tract was started but never
  #  walked, hence no walker records and no associated finds.
  tract_data <-
    tract_data[tract_data$KEY != "uuid:baf35399-aa85-49d6-94fd-a980dd863ca9",]

  #  [T & W] TractNo: nw Tr 5298 with
  #  uuid:1ac61a77-22b6-4357-aa0e-0762fb688a45: Change to TractNo 5542
  #   This tract lies to the south-east end of Orman kampı
     tract_data[tract_data$basic_data.tract_no == 5298 &
                 tract_data$KEY == "uuid:1ac61a77-22b6-4357-aa0e-0762fb688a45",
                 "basic_data.tract_no"] <- 5542

  # [T & W] TEAM B: Typo in TractNo (two times 5221). Problem with
  # data-entry and saving file in GPS. w016 said "keep the second (in
  # time) record".
     tract_data <- tract_data[!(tract_data$basic_data.tract_no == 5221 &
                    tract_data$KEY == "uuid:97ec7225-386c-4bee-a0ad-6613a1fdc81e"),]

  #  T & W] TEAM B: Typo in TractNo (two times 5403 and no 5406).
  #  Change the second 5404 in 5406
     tract_data[tract_data$basic_data.tract_no == 5403 &
                 tract_data$KEY == "uuid:6bbc0b05-d994-4766-a91f-620fe50f6ff8",
                 "basic_data.tract_no"] <- 5406

  # [T & W ] 5424 was used two times. Second one should be 5425
     tract_data[tract_data$basic_data.tract_no == 5424 &
                 tract_data$KEY == "uuid:4da0b263-1bdd-4855-b1eb-243614ca026b",
                 "basic_data.tract_no"] <- 5425

  # [T] Tract nw Tr 5415 with
  # uuid:3a8c99da-b80f-4888-8e29-442e0ed8227a =>
  # Change to TractNo 5543
     tract_data[tract_data$basic_data.tract_no == 5415 &
                 tract_data$KEY == "uuid:3a8c99da-b80f-4888-8e29-442e0ed8227a",
                 "basic_data.tract_no"] <- 5543

  # [T] Tract 5595 with
  # uuid:af25f47b-dd12-41a9-9373-50c2ceffbd49 => Change to Tr 5544
     tract_data[tract_data$basic_data.tract_no == 5595 &
                 tract_data$KEY == "uuid:af25f47b-dd12-41a9-9373-50c2ceffbd49",
                 "basic_data.tract_no"] <- 5544

  # [T]  nw. 5377 => should not be transferred into canonical
  # (as is duplicate of nw. 3791)
  tract_data <-
    tract_data[tract_data$KEY != "uuid:0db9924c-fb17-4398-a550-35475c8db5e0",]

  # [T]  5286 was later rewalked. => Should be excluded from canonical
  tract_data <-
    tract_data[tract_data$KEY != "uuid:a67939f6-a92d-4bec-91a6-9a19ff5b7523",]

  # Missing tract have been added at a latest point using the
  # field notes. Need to change the date of the record
  # [T] Tract 3639, uuid:6dc1be99-5076-4ee9-9664-b67d7a3a4c22
  # --> 9:00-9:10am Turkish local time (or 6.10am UTC) on 2017-08-24
    tract_data[tract_data$KEY ==
               "uuid:6dc1be99-5076-4ee9-9664-b67d7a3a4c22","today"] <-
                 "24-Aug-2017"
    tract_data[tract_data$KEY ==
               "uuid:6dc1be99-5076-4ee9-9664-b67d7a3a4c22","start"] <-
                 "24-Aug-2017 09:00:00"
    tract_data[tract_data$KEY ==
               "uuid:6dc1be99-5076-4ee9-9664-b67d7a3a4c22","end"] <-
                 "24-Aug-2017 09:10:00"




######################################################
##########                                   #########
########                                       #######
#####                                            #####
#                P a N o R m O s                     #
#####                            2 0 1 9         #####
########                                       #######
##########                                   #########
######################################################


# Tract numbering issues:
#
# - [ ] [WT] Tr 57013 -> 5713
     tract_data[tract_data$KEY == "PRFKLT34PEGH8Y16NX9BATT79",
                "basic_data.tract_no"] <- 5713


# - [ ] [WT] Tr 3114 -> 6114
     tract_data[tract_data$KEY == "17TEM1X68YHC85H6ODNHDIEDL",
                 "basic_data.tract_no"] <- 6114



######################################################
##########                                   #########
########                                       #######
#####     E n D                                  #####
#                P a N o R m O s                     #
#####                            2 0 1 9         #####
########                                       #######
##########                                   #########
######################################################


  # Remove duplicate tract_no 5621

     tract_data <- tract_data[tract_data$KEY != "WN5ONYPXKH0W5VW1EP56UX6I5",]


  # Wrong tract_no 5079 <- 5279
     tract_data[tract_data$KEY == "uuid:5e9ab67c-bd90-4cff-9a3f-425f07e72d9a",
                 "basic_data.tract_no"] <- 5279


  # Wrong tract_no 5495 (given 2 times). New track 5999 for new house
     tract_data[tract_data$KEY == "uuid:af25f47b-dd12-41a9-9373-50c2ceffbd49",
                 "basic_data.tract_no"] <- 5999

  # Remove duplicate tract_no 6013
     tract_data <- tract_data[tract_data$KEY != "LHGPBWDTBES5DC7TS3OGZULQ0",]

  # Wrong walker_no
     tract_data[tract_data$KEY == "uuid:bbd736c5-d4f7-4699-8b82-6fc6641d5445",
                 c("walkable_tract_data.num_walkers",
                   "walkable_tract_data.w_data_count")] <- 4

######################################################
##########                                   #########
########                                       #######
#####     E N D                                  #####
#          P A N O R M O S #REMOTE#WEEK              #
#####                            2 0 2 0         #####
########                                       #######
##########                                   #########
######################################################

  # All tracts with id nos. under 1000 should be
  # removed from analysis
  tract_data <- tract_data[tract_data$basic_data.tract_no > 1000,]

# Compare walker data with canonical: need order and characters
tract_data <- tract_data[order(tract_data$basic_data.tract_no), ]
rownames(tract_data) <- 1:nrow(tract_data)

# Change variable names with file description
  tract_data <- subset(tract_data,
                       select = as.character(description_tract_data$ODKExportName))
  colnames(tract_data) <- description_tract_data$Variable
  tract_data <- tract_data[
      colnames(tract_data) != "_NOT_EXPORTED_TO_CANONICAL_"]


# Make a copy of tract_data
tract_data_test <- tract_data

tract_data_test[is.na(tract_data_test)] <- ""
tract_data_test[] <- apply(tract_data_test,
                           2,
                           as.character)

# Read canonical data and make them similar to tract data
tract_data_initial_path <-
  paste0(wd_survey,
         tract_folder_canonical,
         "Tract_general_data.csv")

if (file.exists(tract_data_initial_path)) {
  tract_data_initial <-
    read.csv(tract_data_initial_path,
             stringsAsFactors = FALSE,
             na.strings = c(NA))

  tract_data_initial[is.na(tract_data_initial)] <- ""
  tract_data_initial[] <- apply(tract_data_initial,
                                2,
                                as.character)

  test_diff <- identical(tract_data_test,
                         tract_data_initial)
  rm(tract_data_test, tract_data_initial)



  # Exporting data if needed and user say Y
  if (test_diff == FALSE) {
    while (test_diff != "Y" | test_diff != "N") {
      cat("\n \n The 'tract_data' have been changed and")
      cat("\n the canonical version will be updated.")
      cat("\n Do you agree [Y/N]? ")
      cat("\n (use a capital letter)   :")
      test_diff  <- readChar("stdin", 1)

      if (test_diff == "Y") {
        write.csv(tract_data,
                  file = paste0(wd_survey,
                               tract_folder_canonical,
                               "Tract_general_data.csv"),
                  row.names = FALSE,
                  na = "\"\"",
                  quote = TRUE)
        cat("\n \n")
        cat("Canonical data have been overwritten")
        cat("\n \n")
        break}  # breaks when hit enter

      if (test_diff == "N") {
        cat("\n \n")
        cat("Canonical data have NOT been overwritten")
        cat("\n \n")
        break}  # breaks when hit enter
    }
  } else
    cat("\n \n")
    cat("tract_data are identical to canonical data")
    cat("\n \n")
}

if (!file.exists(tract_data_initial_path)) {
  write.csv(tract_data,
          file = paste0(wd_survey,
                        tract_folder_canonical,
                        "Tract_general_data.csv"),
          row.names = FALSE,
          na = "\"\"",
          quote = TRUE)
  cat("\n \n")
  cat("a file tract_data.csv has been added in the folder canonical")
  cat("\n \n")
}

