#!/usr/bin/Rscript --vanilla

#--------------------------------------------------------------------------------
# Aim: correcting the raw export from ODK
# Author (aut): Néhémie Strupler
# Maintainer (cre): Néhémie Strupler
# Last modified: 2017-09-10
# Licence: CC BY 4.0
#--------------------------------------------------------------------------------

# Load the data ------------------------------------------
## Define fixed variable

wd_survey <- c("../../survey-data/")
tract_folder <- c("tract-data/")
tract_folder_odk <- paste(tract_folder, "export_odk/", sep = "")
tract_folder_canonical <- paste(tract_folder, "canonical/", sep = "")
tract_r2  <- "Tract_r2/Tract_walkable_tract_data_w_data.csv"
tract_r4  <- "Tract_r4/Tract_r4_walkable_tract_data_w_data.csv"
tract_r7  <- "Tract_r7/Tract_r7-w_data.csv"
tract_r10 <- "Tract_r10/Tract_r10-w_data.csv"
tract_r11 <- "Tract_r11/Tract_r11-w_data.csv"
description_tract_walker_data_path <- paste(wd_survey, tract_folder,
                                     "description_canonical_tract-walker-data.csv", sep = "")

### Load the walker data
walker_data_r2 <-
  read.csv(paste(wd_survey, tract_folder_odk, tract_r2, sep = ""),
           encoding = "UTF-8")

walker_data_r4 <-
  read.csv(paste(wd_survey, tract_folder_odk, tract_r4, sep = ""),
                encoding = "UTF-8")

walker_data_r7 <-
  read.csv(paste(wd_survey, tract_folder_odk, tract_r7, sep = ""),
                encoding = "UTF-8")

walker_data_r10 <-
  read.csv(paste(wd_survey, tract_folder_odk, tract_r10, sep = ""),
                encoding = "UTF-8")

walker_data_r11 <-
  read.csv(paste(wd_survey, tract_folder_odk, tract_r11, sep = ""),
                encoding = "UTF-8")

walker_data <- rbind(walker_data_r2, walker_data_r4)
rm(walker_data_r2, walker_data_r4)

### ABOUT R2 AND R4: After the first days of working with a first version of the
### ODK from (r2), some modifications have been made to improve it. Even if the
### name of the walker data file site was modified, the changes didn't affect
### the newer version (r4) of walker_data

walker_data$w_distribution_skew <- NA
walker_data$w_find_condition <- NA
walker_data$w_find_fragmentsize <- NA
walker_data <- rbind(walker_data, walker_data_r7,
                     walker_data_r10, walker_data_r11 )
rm(walker_data_r7, walker_data_r10, walker_data_r11)

### ABOUT R7: Modification for 2017 survey


description_tract_walker_data <-
  read.csv(description_tract_walker_data_path,
           encoding = "UTF-8", na.strings = c(NA,""))

description_tract_walker_data <- description_tract_walker_data[description_tract_walker_data$Variable
!= "_NOT_EXPORTED_TO_CANONICAL_",]

# Tract data corrections ------------------------------

  ## Remove duplicate form ODK export
  walker_data <- unique(walker_data)

  ## Tr 3481 has been incorrectly labelled 481
     walker_data[walker_data$w_tract_no == 481 &
                 walker_data$PARENT_KEY == "uuid:2616bee5-8dd5-4be5-b044-be5300689028",
                 "w_tract_no"] <- 3481


  ## Tr 3012 has not be digitized: it is not an important tract however,
  ## as it was later walked as 3500)
  walker_data <- walker_data[walker_data$w_tract_no != 3012, ]

  ## Tr 3008 is duplicated with identical data but different keys
  ## (presumably it has   somehow been submitted twice).
  #3  We should ignore the first entry (uuid: ...c2c3)
  walker_data <- walker_data[walker_data$PARENT_KEY !=
            "uuid:32a318f3-340e-4c51-ace0-69799568c2c3",]

# Corrections which need to be made to raw Tract data in order to accurately
# reflect reality/correct errors:

  ## to correct a problem related to walker walking twice in same tract which
  ## causes problems with survey recording new walker number has been introduced
  ## (www0)

  ## Tr 3026, w002, 1st from left should be w000
  ## Tr 3027, w010, 1st from left should be w000
     walker_data$w_no <- as.character(walker_data$w_no)
     walker_data[walker_data$w_tract_no %in% c(3026,3027) &
               walker_data$w_position == "fromleft1", "w_no"] <- "w000"

  ## Tr 3044, 4th from left w002 should be w010
     walker_data[walker_data$w_tract_no == 3044 &
                 walker_data$w_position == "fromleft4", "w_no"] <- "w010"

  ## Tr 3045, 3rd from left w007 should be w009
     walker_data[walker_data$w_tract_no == 3045 &
               walker_data$w_position == "fromleft3", "w_no"] <- "w009"

  ## Tr 3049, 2nd from left w015 should be w012
     walker_data[walker_data$w_tract_no == 3049 &
                 walker_data$w_position == "fromleft2", "w_no"] <- "w012"

  ## w014 should instead be w011 in all the following records
  ## w014 was NOT present on the date of these walks):
  ## 3083, 3084, 3085, 3086, 3087, 3088, 3089, 3090, 3091, 3092, 3093, 3094,
     walker_data[walker_data$w_tract_no %in%
                   c(3077, 3078, 3079, 3080, 3081,
                     3083, 3084, 3085, 3086, 3087, 3088, 3089,
                     3090, 3091, 3092, 3093, 3094) &
                 walker_data$w_no == "w014", "w_no"] <- "w011"

  ## Tr 3098, w006 should be recorded as 2nd from left
     walker_data[walker_data$w_tract_no == 3098 &
                 walker_data$w_position == "fromleft2", "w_no"] <- "w006"

  ## Tr 3113, walker positions are wrong, should be:
  ## w004 1st from L; w010 2nd; w009 3rd; w006 4th; w001 5th from L
     walker_data[walker_data$w_tract_no == 3113 &
                 walker_data$w_no == "w004", "w_position"] <- "fromleft1"
     walker_data[walker_data$w_tract_no == 3113 &
                 walker_data$w_no == "w010", "w_position"] <- "fromleft2"
     walker_data[walker_data$w_tract_no == 3113 &
                 walker_data$w_no == "w006", "w_position"] <- "fromleft4"
     walker_data[walker_data$w_tract_no == 3113 &
                 walker_data$w_no == "w001", "w_position"] <- "fromleft5"


  ## Tr 3117 has been mistakenly entered as 3116 (i.e. there are two entries for 3116)
  ## The later 3116 should be renamed 3117
     walker_data[walker_data$w_tract_no == 3116 &
                 walker_data$PARENT_KEY == "uuid:628ffc43-cb0d-4a6e-87c3-a95dcc43b317",
                 "w_tract_no"] <- 3117

  ## Tr 3125: here w006 appears twice
  ## w006 5th from L should be w010
     walker_data[walker_data$w_tract_no == 3125 &
                 walker_data$w_position == "fromleft5", "w_no"] <- "w010"

     walker_data[walker_data$w_tract_no == 3111 &
                 walker_data$w_position == "fromleft5", "w_no"] <- "w010"

  ## Tr 3176 has been mistakenly entered as 3175 (i.e. there are two entries for 3175)
  ## the later 3175 should be 3176
     walker_data[walker_data$w_tract_no == 3175 &
                 walker_data$PARENT_KEY == "uuid:84d96bae-43d5-4be9-b135-fb2ac2ffb2e5",
                 "w_tract_no"] <- 3176

  # Tr 3134, w012 1st from left should be w010
     walker_data[walker_data$w_tract_no == 3134 &
                 walker_data$w_position == "fromleft1", "w_no"] <- "w010"

  # Tr 3149, w012 3rd from left should be w010
     walker_data[walker_data$w_tract_no == 3149 &
                 walker_data$w_position == "fromleft3", "w_no"] <- "w010"

  # [TW] Tr 32303 should be 3203
     walker_data[walker_data$w_tract_no == 32303, "w_tract_no"] <- 3203

  # [W] Tr 3229, walker positions wrong, should be
  # w006 1st from L
  # w011 2nd from L
     walker_data[walker_data$w_tract_no == 3229 &
                 walker_data$w_no == "w006", "w_position"] <- "fromleft1"
     walker_data[walker_data$w_tract_no == 3229 &
                 walker_data$w_no == "w011", "w_position"] <- "fromleft2"


  # Tr 3231, here w009 appears twice
  #  w009 5th from left should be w006
     walker_data[walker_data$w_tract_no == 3231 &
                 walker_data$w_position == "fromleft5", "w_no"] <- "w006"

  # Tr 3234, walker positions
  #  w011 should be 3rd from L
  #  w006 should be 4th from L
     walker_data[walker_data$w_tract_no == 3234 &
                 walker_data$w_no == "w011", "w_position"] <- "fromleft3"
     walker_data[walker_data$w_tract_no == 3234 &
                 walker_data$w_no == "w006", "w_position"] <- "fromleft4"

  # [W] Tr 3236, w012 should be 1st from L
     walker_data[walker_data$w_tract_no == 3236 &
                 walker_data$w_no == "w012", "w_position"] <- "fromleft1"

  # [W] Tr 3245, w009 should be 2nd from L
     walker_data[walker_data$w_tract_no == 3245 &
                 walker_data$w_no == "w009", "w_position"] <- "fromleft2"

  ## [W] Tr 3260 does not exist as track [Was rewalked as 3474]
  walker_data <- walker_data[walker_data$PARENT_KEY !=
            "uuid:446ebc9f-310c-4b45-a85b-407885bf9a0a",]

  # [W] Tr 3259, w006 should be 5th from L
     walker_data[walker_data$w_tract_no == 3259 &
                 walker_data$w_no == "w006", "w_position"] <- "fromleft5"

  # [W] Tr 3262, w012 should be 1st from L
     walker_data[walker_data$w_tract_no == 3262 &
                 walker_data$w_no == "w012", "w_position"] <- "fromleft1"

  # [W] Tr 5072, w012 should be w010
     walker_data[walker_data$w_tract_no == 5072 &
                 walker_data$w_no == "w012", "w_no"] <- "w010"

  # [W] Tr 3282, should be:
  #  w006, should be 1st from left
  #  w011, should be 2nd from left
  #  w009, should be 3rd from left
  #  w012, should be 4th from left
  #  w004, should be 5th from left
     walker_data[walker_data$w_tract_no == 3282 &
                 walker_data$w_no == "w006", "w_position"] <- "fromleft1"
     walker_data[walker_data$w_tract_no == 3282 &
                 walker_data$w_no == "w011", "w_position"] <- "fromleft2"
     walker_data[walker_data$w_tract_no == 3282 &
                 walker_data$w_no == "w009", "w_position"] <- "fromleft3"
     walker_data[walker_data$w_tract_no == 3282 &
                 walker_data$w_no == "w012", "w_position"] <- "fromleft4"
     walker_data[walker_data$w_tract_no == 3282 &
                 walker_data$w_no == "w004", "w_position"] <- "fromleft5"


  # [W] Tr 3288, 3rd from left should be w009
     walker_data[walker_data$w_tract_no == 3288 &
                 walker_data$w_position == "fromleft3", "w_no"] <- "w009"

  # [W] Tr 3299, 3rd from left should be w009
  #   walker_data[walker_data$w_tract_no == 3299 &
  #               walker_data$w_position == "fromleft3", "w_no"] <- "w009"

  # [W] Tr 3289 should be:
  #  1st from L, w006
  #  2nd from L, w011
  #  3rd from L, w009
  #  4th from L, w012
  #  5th from L, w004
     walker_data[walker_data$w_tract_no == 3289 &
                 walker_data$w_position == "fromleft1", "w_no"] <- "w006"
     walker_data[walker_data$w_tract_no == 3289 &
                 walker_data$w_position == "fromleft2", "w_no"] <- "w011"
     walker_data[walker_data$w_tract_no == 3289 &
                 walker_data$w_position == "fromleft3", "w_no"] <- "w009"
     walker_data[walker_data$w_tract_no == 3289 &
                 walker_data$w_position == "fromleft4", "w_no"] <- "w012"
     walker_data[walker_data$w_tract_no == 3289 &
                 walker_data$w_position == "fromleft5", "w_no"] <- "w004"

  # [W] 3298 has been incorrectly entered as 3290 (hence there are duplicate 3290s)
  # Tr 3298 has a uuid: ...bfdc
     walker_data[walker_data$w_tract_no == 3290 &
                 walker_data$PARENT_KEY == "uuid:b01d7ec2-d6ed-4719-9b61-c92532e4bfdc",
                 "w_tract_no"] <- 3298


  # [W] Tr 33666 should be 3366
     walker_data[walker_data$w_tract_no == 33666, "w_tract_no"] <- 3366

  # [W] Tr 5090 have been entered as 5060
     walker_data[walker_data$PARENT_KEY ==
                   "uuid:4066628f-9abe-4794-92d4-d91a8101b021",
                 "w_tract_no"] <- 5090

  # [W] Tr 3313, 2nd from L should be w010
     walker_data[walker_data$w_tract_no == 3313 &
                 walker_data$w_position == "fromleft2", "w_no"] <- "w010"

  # [W] Tr 3317, 4th from L should be w010
     walker_data[walker_data$w_tract_no == 3317 &
                 walker_data$w_position == "fromleft4", "w_no"] <- "w010"

  # [W] Tr 3355 has been entered as 3354 (hence there are duplicate 3354s)
  # Tr 3355 has uuid of: ...16e5
     walker_data[walker_data$PARENT_KEY ==
                  "uuid:b5f75d6b-76ec-4524-9e24-450fd51316e5",
                 "w_tract_no"] <- 3355

  # [W] Tr 3362, 1st from L should be w010
     walker_data[walker_data$w_tract_no == 3362 &
                 walker_data$w_position == "fromleft1", "w_no"] <- "w010"

  # [W] Tr 3364, 1st from L should be w010
     walker_data[walker_data$w_tract_no == 3364 &
                 walker_data$w_position == "fromleft1", "w_no"] <- "w010"

  # [W] Tr 3369, 1st from L should be w010
     walker_data[walker_data$w_tract_no == 3369 &
                 walker_data$w_position == "fromleft1", "w_no"] <- "w010"

  # [W] Tr 3383, 2nd from L should be w012
     walker_data[walker_data$w_tract_no == 3383 &
                 walker_data$w_position == "fromleft2", "w_no"] <- "w012"

  # [W] Tr 3401, 5th from L should be w006
     walker_data[walker_data$w_tract_no == 3401 &
                 walker_data$w_position == "fromleft5", "w_no"] <- "w006"


  # [W] Tr 3402, 1st from L should be w010
     walker_data[walker_data$w_tract_no == 3402 &
                 walker_data$w_position == "fromleft1", "w_no"] <- "w010"

  # [W] Tr 3404, 1st from L should be w010
     walker_data[walker_data$w_tract_no == 3404 &
                 walker_data$w_position == "fromleft1", "w_no"] <- "w010"

  # [W] Tr 3411 has been labelled 3410 (i.e. there are duplicate 3410)
  # Tr 3411 has uuid of ...5c9f
     walker_data[walker_data$w_tract_no == 3410 &
                 walker_data$PARENT_KEY == "uuid:3e2678a1-7b20-45c4-af1f-20c25d135c9f",
                 "w_tract_no"] <- 3411

  # [W] Tr 3432, 4th from left should be w009
     walker_data[walker_data$w_tract_no == 3432 &
                 walker_data$w_position == "fromleft4", "w_no"] <- "w009"

  # [W] Tr 3466 has been labelled 3465 (i.e. there are duplicate 3465)
  #  Tr 3466 has uuid of ...3179
     walker_data[walker_data$w_tract_no == 3465 &
                 walker_data$PARENT_KEY == "uuid:df9cca40-bf2a-48f0-8395-a6ac60c43179",
                 "w_tract_no"] <- 3466

  # [W] Tr 3473
  #  w005 should be 2nd from L
  #  w012 should be w010
     walker_data[walker_data$w_tract_no == 3473 &
                 walker_data$w_no == "w012", "w_no"] <- "w010"
     walker_data[walker_data$w_tract_no == 3473 &
                 walker_data$w_no == "w005", "w_position"] <- "fromleft2"

  # [W] Tr 3478 w010 should be 2nd from L
     walker_data[walker_data$w_tract_no == 3478 &
                 walker_data$w_no == "w010", "w_position"] <- "fromleft2"

  # [W] Tr 3483 has been incorrectly labelled 3477 (hence there are duplicate 3477)
  #  Tr 3483 is a 4 walker and has a uuid of ...ca9e
     walker_data[walker_data$w_tract_no == 3477 &
                 walker_data$PARENT_KEY == "uuid:0056af41-ac04-4d6e-8d25-37081a32ca9e",
                 "w_tract_no"] <- 3483

   # [W]  3653 - w017 appears twice -
   # KEY="uuid:c02c699e-4f9b-4107-9f42-efe3f71c2fbc/walkable_tract_data-w_data[1]"
   # w017 => should instead be w020
        walker_data[walker_data$w_tract_no == 3653 &
                 walker_data$KEY == "uuid:c02c699e-4f9b-4107-9f42-efe3f71c2fbc/walkable_tract_data-w_data[1]",
                 "w_no"] <- "w020"

   # [W] 3677 - missing walker data for fromleft3 (w004?) -
   # KEY="uuid:03011101-7f1e-44ef-bf9c-859cfd965cbe/walkable_tract_data-w_data[3]"
   # fromleft1 => should be "fromleft3"
     walker_data[walker_data$w_tract_no == 3677 &
                 walker_data$KEY == "uuid:03011101-7f1e-44ef-bf9c-859cfd965cbe/walkable_tract_data-w_data[3]",
                 "w_position"] <- "fromleft3"

   # [W] 3730 -  two times fromleft4 and no fromleft2
   # KEY="uuid:ae0117f8-e7b9-46ed-9a2a-464e4e0bbff4/walkable_tract_data-w_data[4]"
   # fromleft4 => should be "fromleft2"
     walker_data[walker_data$w_tract_no == 3730 &
                 walker_data$KEY == "uuid:ae0117f8-e7b9-46ed-9a2a-464e4e0bbff4/walkable_tract_data-w_data[4]",
                 "w_position"] <- "fromleft2"

   # [W] 3736 two times fromleft4 and two times fromleft5
   # KEY="uuid:1d1830f3-c9df-4c25-b346-070960ff3629/walkable_tract_data-w_data[5]"
   # fromleft5 => should be "fromleft1";
   # KEY="uuid:1d1830f3-c9df-4c25-b346-070960ff3629/walkable_tract_data-w_data[4]"
   # fromleft4 => should be "fromleft2"
     walker_data[walker_data$w_tract_no == 3736 &
                 walker_data$KEY == "uuid:1d1830f3-c9df-4c25-b346-070960ff3629/walkable_tract_data-w_data[5]",
                 "w_position"] <- "fromleft1"
     walker_data[walker_data$w_tract_no == 3736 &
                 walker_data$KEY == "uuid:1d1830f3-c9df-4c25-b346-070960ff3629/walkable_tract_data-w_data[4]",
                 "w_position"] <- "fromleft2"

  # [W] 3741 - w020 is fromleft1 and should be fromleft5
     walker_data[walker_data$w_tract_no == 3741 &
                 walker_data$w_no == "w020", "w_position"] <- "fromleft5"

  # [W] 3838 - w021 should be fromleft5
     walker_data[walker_data$w_tract_no == 3838 &
                 walker_data$w_no == "w021", "w_position"] <- "fromleft5"

   # [W] 3814 - w021 appears twice
   #  KEY="uuid:ad80300f-d7ce-4b14-a7d3-64a2183d4069/walkable_tract_data-w_data[3]"
   #  w021 => should be w016
     walker_data[walker_data$w_tract_no == 3814 &
                 walker_data$KEY == "uuid:ad80300f-d7ce-4b14-a7d3-64a2183d4069/walkable_tract_data-w_data[3]",
                 "w_no"] <- "w016"

  # [W] Tr 5340 should be labelled Tr 3540
     walker_data[walker_data$w_tract_no == 5340 &
                 walker_data$PARENT_KEY == "uuid:ba2e5229-6e47-4afe-8ac3-1be06b3421ef",
                 "w_tract_no"] <- 3540

  # [W] Tr 3546, w010 should be deleted
   walker_data <- walker_data[walker_data$KEY !=
            "uuid:00f9c421-946b-4759-9620-57e623c7b39e/walkable_tract_data-w_data[5]",]

  # [W] Tr 3551, w009 should be w006
     walker_data[walker_data$w_tract_no == 3551 &
                 walker_data$w_no == "w009", "w_no"] <- "w006"

  # [W] Tr 3557, w011 should be 3rd from L
     walker_data[walker_data$w_tract_no == 3478 &
                 walker_data$w_no == "w011", "w_position"] <- "fromleft3"

  # [W] Tr 3507 has been incorrectly labelled 5507
     walker_data[walker_data$w_tract_no == 5507 &
                 walker_data$PARENT_KEY == "uuid:93b66cc6-9224-4148-b506-ff87fe869798",
                 "w_tract_no"] <- 3507

  # [W] ODK data for Tracts
  # 3503, 3504, 3505 or 3506 has been wrongly labelled
  # 4503, 4504, 4505,or 4506

     walker_data[walker_data$w_tract_no == 4503 &
                 walker_data$PARENT_KEY == "uuid:91475bb0-032f-47c1-879f-d5ac475e6808",
                 "w_tract_no"] <- 3503
     walker_data[walker_data$w_tract_no == 4504 &
                 walker_data$PARENT_KEY == "uuid:1214bae8-033e-4774-bdd1-4c10aee827fc",
                 "w_tract_no"] <- 3504
     walker_data[walker_data$w_tract_no == 4505 &
                 walker_data$PARENT_KEY == "uuid:16fae20b-9b60-46c5-802b-d3f979f53c09",
                 "w_tract_no"] <- 3505
     walker_data[walker_data$w_tract_no == 4506 &
                 walker_data$PARENT_KEY == "uuid:68ade9a8-8cf7-436f-9211-b5d6204c1566",
                 "w_tract_no"] <- 3506


    # [W] Tr 3511, w005: visibility should 97 not 973%.
     walker_data[walker_data$w_tract_no == 3511 &
                 walker_data$w_no == "w005", "w_visibility"] <- 97

     # [W] 3674 remove w006. It's a typo for this 4 walkers tract
     walker_data <-
       walker_data[!(walker_data$w_tract_no == 3674 &
                     walker_data$w_no == "w006"),]


     # [T & W] Wrong number from TEAM A. Rename 5420 -> 3816,
     # 5421 -> 3817, 5422 -> 3818, 5423 -> 3819, 5424 -> 3820, 5425 -> 3821
     walker_data[walker_data$w_tract_no == 5420 &
                 walker_data$PARENT_KEY == "uuid:ba74b8c6-fce2-45da-847c-5cb140a20b79",
                 "w_tract_no"] <- 3816
     walker_data[walker_data$w_tract_no == 5421 &
                 walker_data$PARENT_KEY == "uuid:a7f1e2bd-2173-427f-8235-5af06ffcb9ff",
                 "w_tract_no"] <- 3817
     walker_data[walker_data$w_tract_no == 3422 &
                 walker_data$PARENT_KEY == "uuid:523f0c64-8365-4465-b62b-802bb5c159b3",
                 "w_tract_no"] <- 3818
     walker_data[walker_data$w_tract_no == 5426 &
                 walker_data$PARENT_KEY == "uuid:e4681a8d-fd4e-41cd-8d5f-24b4f939d909",
                 "w_tract_no"] <- 3819
     walker_data[walker_data$w_tract_no == 5424 &
                 walker_data$PARENT_KEY == "uuid:a499b55f-098f-46d0-9500-7b93c27eeb15",
                 "w_tract_no"] <- 3820
     walker_data[walker_data$w_tract_no == 5425 &
                 walker_data$PARENT_KEY == "uuid:f6ce6c8a-abb8-4d8d-bc8c-ee97ba498cc1",
                 "w_tract_no"] <- 3821


     # T & W] TEAM A: Typo in TractNo (two times 3614 and no 3615).
     # Change the second 3614 in 3615
     walker_data[walker_data$w_tract_no == 3614 &
                 walker_data$PARENT_KEY == "uuid:66832a54-f684-4b5d-8fd0-2002af24f95c",
                 "w_tract_no"] <- 3615

  # [T & W] TEAM A: Typo in TractNo 6672.
  # Change 6672 in 3672
     walker_data[walker_data$w_tract_no == 6672 &
                 walker_data$PARENT_KEY == "uuid:64505d19-58de-4ef2-a6eb-aaac8d55d583",
                 "w_tract_no"] <- 3672

  #  [T & W] TEAM A: Typo in TractNo (two times 3749 and no 3748).
  #  Change the second 3749 in 3748
     walker_data[walker_data$w_tract_no == 3749 &
                 walker_data$PARENT_KEY == "uuid:430dd6dd-00d3-4891-913c-4d32fdb6f5f4",
                 "w_tract_no"] <- 3748

  #  [W] 3755 - KEY="uuid:9c43c51b-85ee-41f8-92fa-214db6463429/walkable_tract_data-w_data[1]"
  #  w004 fromleft1 => should be w025 [according to paper list]
     walker_data[walker_data$KEY == "uuid:9c43c51b-85ee-41f8-92fa-214db6463429/walkable_tract_data-w_data[1]",
                 "w_no"] <- "w025"

  #  [T & W] first 3799 [
  #  KEY="uuid:ee233f98-bce2-4dc3-bfb3-70a222f2cf1b"] =>
  #  TractNo should be 3798
     walker_data[walker_data$PARENT_KEY == "uuid:ee233f98-bce2-4dc3-bfb3-70a222f2cf1b",
                 "w_tract_no"] <- 3798

  #  [T & W] TEAM A: Typo in TractNo (two times 3818 and no 3815).
  #  Change the first 3818 in 3815
     walker_data[walker_data$w_tract_no == 3818 &
                 walker_data$PARENT_KEY == "uuid:f99e059c-ab5d-4abf-a58e-bebbfe7e1cf4",
                 "w_tract_no"] <- 3815


  #  [W] 5150 - w019 should be fromleft3
     walker_data[walker_data$w_tract_no == 5150 &
                 walker_data$w_no == "w019", "w_position"] <- "fromleft3"
  #   [W] 5151 - w019 appears twice,
  #   fromleft2; KEY="uuid:31ad2bc5-3fe5-4417-899a-b674db05c298/walkable_tract_data-w_data[1]"
  #   w019 => should be w002
     walker_data[walker_data$KEY == "uuid:31ad2bc5-3fe5-4417-899a-b674db05c298/walkable_tract_data-w_data[1]",
                 "w_no"] <- "w002"
  # [W] 5159: w016
  # [KEY="uuid:dedc4ee0-eea2-4646-b92b-8bc727bd5f5f/walkable_tract_data-w_data[5]"]
  # fromleft1 => should be fromleft5
  # [W] 5159: w026
  # [KEY="uuid:dedc4ee0-eea2-4646-b92b-8bc727bd5f5f/walkable_tract_data-w_data[4]"]
  # fromleft2 => should be fromleft4
     walker_data[walker_data$KEY == "uuid:dedc4ee0-eea2-4646-b92b-8bc727bd5f5f/walkable_tract_data-w_data[5]",
                 "w_position"] <- "fromleft5"
     walker_data[walker_data$KEY == "uuid:dedc4ee0-eea2-4646-b92b-8bc727bd5f5f/walkable_tract_data-w_data[4]",
                 "w_position"] <- "fromleft4"

  # [W] 5160: w026
  # KEY="uuid:3c99f58e-9689-4a39-acf0-6345ee4e1242/walkable_tract_data-w_data[4]"]
  # fromleft2 => should be fromleft4
  # [W] 5160: w016
  # [KEY="uuid:3c99f58e-9689-4a39-acf0-6345ee4e1242/walkable_tract_data-w_data[5]"]
  # fromleft1 => should be fromleft5
     walker_data[walker_data$KEY == "uuid:3c99f58e-9689-4a39-acf0-6345ee4e1242/walkable_tract_data-w_data[4]",
                 "w_position"] <- "fromleft4"
     walker_data[walker_data$KEY == "uuid:3c99f58e-9689-4a39-acf0-6345ee4e1242/walkable_tract_data-w_data[5]",
                 "w_position"] <- "fromleft5"


  #  [W] 5174 - w002 should be fromleft5
     walker_data[walker_data$w_tract_no == 5174 &
                 walker_data$w_no == "w002", "w_position"] <- "fromleft5"

  #  [W] 5182 - w002 should be fromleft5
     walker_data[walker_data$w_tract_no == 5182 &
                 walker_data$w_no == "w002", "w_position"] <- "fromleft5"

  # [T & W] TEAM B: Typo in TractNo (two times 5221). Problem with
  # data-entry and saving file in GPS. w016 said "keep the second (in
  # time) record".
     walker_data <- walker_data[!(walker_data$w_tract_no == 5221 &
                    walker_data$PARENT_KEY == "uuid:97ec7225-386c-4bee-a0ad-6613a1fdc81e"),]

  #  [W] 5224 - w016 should be fromleft1 and w025 fromleft4
     walker_data[walker_data$w_tract_no == 5224 &
                 walker_data$w_no == "w016", "w_position"] <- "fromleft1"
     walker_data[walker_data$w_tract_no == 5224 &
                 walker_data$w_no == "w025", "w_position"] <- "fromleft4"

  #  [W] 5227 - w019 should be formleft3
     walker_data[walker_data$w_tract_no == 5227 &
                 walker_data$w_no == "w019", "w_position"] <- "fromleft3"

  #  [W] 5247 - w025 should be fromleft5, w002 should be fromleft4
     walker_data[walker_data$w_tract_no == 5247 &
                 walker_data$w_no == "w025", "w_position"] <- "fromleft5"
     walker_data[walker_data$w_tract_no == 5247 &
                 walker_data$w_no == "w002", "w_position"] <- "fromleft4"

  #  [W] 5268 - w019 should be fromleft3
     walker_data[walker_data$w_tract_no == 5268 &
                 walker_data$w_no == "w019", "w_position"] <- "fromleft3"

  # [W] 5291 w025
  # KEY="uuid:79764bb7-7809-426d-ac41-97c1d57962b9/walkable_tract_data-w_data[4]"
  # fromleft3 => should be fromleft4
     walker_data[walker_data$KEY == "uuid:79764bb7-7809-426d-ac41-97c1d57962b9/walkable_tract_data-w_data[4]",
                 "w_position"] <- "fromleft4"

  # [W] 5334 - walker nos. totally off. Paper backup confirms: should
  # be fromleft1->5 w017, w022, w002, w021, w016
  # (KEY="uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[1]" to "...[5]"
  # respectively
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[1]",
                 "w_position"] <- "fromleft1"
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[1]",
                 "w_no"] <- "w017"
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[2]",
                 "w_position"] <- "fromleft2"
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[2]",
                 "w_no"] <- "w022"
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[3]",
                 "w_position"] <- "fromleft3"
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[3]",
                 "w_no"] <- "w002"
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[4]",
                 "w_position"] <- "fromleft4"
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[4]",
                 "w_no"] <- "w021"
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[5]",
                 "w_position"] <- "fromleft5"
     walker_data[walker_data$w_tract_no == 5334 &
                 walker_data$KEY == "uuid:03346d7b-985f-4d82-a8ff-81b1bbdd5c45/walkable_tract_data-w_data[5]",
                 "w_no"] <- "w016"
  #  [W] 5336 - w026 should be w016
     walker_data[walker_data$w_tract_no == 5336 &
                 walker_data$w_no == "w026", "w_no"] <- "w016"

  # [W] 5351 - KEY="uuid:24a68333-c4ba-4446-af8a-b841000ddb62/walkable_tract_data-w_data[1]"
  # w023 => should be w025
     walker_data[walker_data$KEY == "uuid:24a68333-c4ba-4446-af8a-b841000ddb62/walkable_tract_data-w_data[1]",
                 "w_no"] <- "w025"

   #  [W] 5358 - w021 should be fromleft4
     walker_data[walker_data$w_tract_no == 5358 &
                 walker_data$w_no == "w021", "w_position"] <- "fromleft4"

  #  [W] 5361 - check  KEY="uuid:eba4cb71-c3a7-4972-a7d7-3da1389f2f50/walkable_tract_data-w_data[3]"
  #  w025 => should be w002
     walker_data[walker_data$KEY == "uuid:eba4cb71-c3a7-4972-a7d7-3da1389f2f50/walkable_tract_data-w_data[3]", "w_no"] <- "w002"

  #  [W] 5388 - w001 should be fromleft4
     walker_data[walker_data$w_tract_no == 5388 &
                 walker_data$w_no == "w001", "w_position"] <- "fromleft4"


  #  T & W] TEAM B: Typo in TractNo (two times 5403 and no 5406).
  #  Change the second 5404 in 5406
     walker_data[walker_data$w_tract_no == 5403 &
                 walker_data$PARENT_KEY == "uuid:6bbc0b05-d994-4766-a91f-620fe50f6ff8",
                 "w_tract_no"] <- 5406

  #  [W] 5415 - w001 should be fromleft2
     walker_data[walker_data$w_tract_no == 5415 &
                 walker_data$w_no == "w001", "w_position"] <- "fromleft2"

  # 5419
  # w004
  # [KEY="uuid:e9b4c3a3-c9e9-4606-a00e-28f116b62d35/walkable_tract_data-w_data[5]"]
  # should be fromleft5;
  # w021
  # [KEY="uuid:e9b4c3a3-c9e9-4606-a00e-28f116b62d35/walkable_tract_data-w_data[2]"]
  # should be from fromleft2;
  # w022
  # [KEY="uuid:e9b4c3a3-c9e9-4606-a00e-28f116b62d35/walkable_tract_data-w_data[4]"]
  # should be fromleft4
     walker_data[walker_data$PARENT_KEY == "uuid:e9b4c3a3-c9e9-4606-a00e-28f116b62d35/walkable_tract_data-w_data[5]",
                 "w_position"] <- "fromleft5"
     walker_data[walker_data$PARENT_KEY == "uuid:e9b4c3a3-c9e9-4606-a00e-28f116b62d35/walkable_tract_data-w_data[2]",
                 "w_position"] <- "fromleft2"
     walker_data[walker_data$PARENT_KEY == "uuid:e9b4c3a3-c9e9-4606-a00e-28f116b62d35/walkable_tract_data-w_data[4]",
                 "w_position"] <- "fromleft4"

   # [W] 5420 - w016 should be fromleft4
       walker_data[walker_data$w_tract_no == 5420 &
                 walker_data$w_no == "w016",
                 "w_position"] <- "fromleft4"

     # [T & W ] 5424 was used two times. Second one should be 5425
     walker_data[walker_data$w_tract_no == 5424 &
                 walker_data$PARENT_KEY == "uuid:4da0b263-1bdd-4855-b1eb-243614ca026b",
                 "w_tract_no"] <- 5425


     ############################################################
     #############                                   ############
     ###########                                       ##########
     ########                                            ########
     ####                P a N o R m O s                     ####
     ########                            2 0 1 9         ########
     ###########                                       ##########
     #############                                   ############
     ############################################################


# Tract numbering issues:
#
# - [ ] [WT] Tr 57013 -> 5713
     walker_data[walker_data$w_tract_no == 57013 &
                 walker_data$PARENT_KEY == "PRFKLT34PEGH8Y16NX9BATT79",
                 "w_tract_no"] <- 5713


# - [ ] [WT] Tr 3114 -> 6114
     walker_data[walker_data$w_tract_no == 3114 &
                 walker_data$PARENT_KEY == "17TEM1X68YHC85H6ODNHDIEDL",
                 "w_tract_no"] <- 6114

# Finds which should be rejected from counts (so "diagnostic" should
# be unticked), because they were not real finds (e.g. stones
# instead of ceramic, or lost).
#
# Diagnostic, lithic, other, obsidian or metallic needs to changed to
# "unticked"/false.
#
# - [ ] [W] 3919 w002, not obsidian, not lithic
  walker_data[walker_data$PARENT_KEY == "HG1AF6H5Y7RJ7RKADE0V4OOWL" &
              walker_data$w_no == "w002",
              "w_lithic_count"] <- 0
  walker_data[walker_data$PARENT_KEY == "HG1AF6H5Y7RJ7RKADE0V4OOWL" &
              walker_data$w_no == "w002",
                 "w_obsidian"] <- "no"

# - [ ] [W] 5765 w032, not diagnostic
  walker_data[walker_data$PARENT_KEY == "AXZHLAJ0WFQJXXLWCYUF7YU9E" &
              walker_data$w_no == "w032",
              "w_lithic_count"] <- 0

# - [ ] [W] 5676 w039, not diagnostic
  walker_data[walker_data$PARENT_KEY == "RCN4C1SV3KQ64EDKYM56MKJSZ" &
              walker_data$w_no == "w029",
              "w_lithic_count"] <- 0

# - [ ] [W] 5691 w038, not lithic
  walker_data[walker_data$PARENT_KEY == "ETZJQ4VNPQ7SYKHWWS2ZK43CO" &
              walker_data$w_no == "w038",
              "w_lithic_count"] <- 0

# - [ ] [W] 3950 w030, not lithic
  walker_data[walker_data$PARENT_KEY == "6SFYW7ON9YRIOL2KUARNAGT1F" &
              walker_data$w_no == "w030",
              "w_lithic_count"] <- 0

# - [ ] [W] 5714 w030, not lithic
  walker_data[walker_data$PARENT_KEY == "9LGOAOK60SE4ANUFHE34C65PT" &
              walker_data$w_no == "w030",
              "w_lithic_count"] <- 0

# - [ ] [W] 5652 w001, not metal, not other
  walker_data[walker_data$PARENT_KEY == "WZN8XU7JG7ZSNFTWBV2PNX7N3" &
              walker_data$w_no == "w001",
              "w_metallic_object"] <- "no"

# - [ ] [W] 5668 w028, not metal, not other
  walker_data[walker_data$PARENT_KEY == "U5RPMM5F6YPACOQYBBNVESB5P" &
              walker_data$w_no == "w028",
              "w_other_count"] <- "no"

# - [ ] [W] 5693 w031, not metal, not other
  walker_data[walker_data$PARENT_KEY == "C21MJS9RCYM7C9ZC0FRLVKMIH" &
              walker_data$w_no == "w031",
              "w_metallic_object"] <- "no"

  walker_data[walker_data$PARENT_KEY == "C21MJS9RCYM7C9ZC0FRLVKMIH" &
              walker_data$w_no == "w031",
              "w_comments"] <- ""



     ############################################################
     #############                                   ############
     ###########                                       ##########
     ########     E n D                                  ########
     ####                P a N o R m O s                     ####
     ########                            2 0 1 9         ########
     ###########                                       ##########
     #############                                   ############
     ############################################################

    # [Visibility error] found with data integrity checking
     walker_data[walker_data$w_tract_no == 3880 &
                 walker_data$w_no == "w031", "w_visibility"] <- 75 # from 757

  # Remove duplicate tract_no 5621
     walker_data <- walker_data[!  walker_data$PARENT_KEY == "WN5ONYPXKH0W5VW1EP56UX6I5", ]

    # Remove walker that couldn't walk
     walker_data <- walker_data[! walker_data$KEY == "uuid:b027ee7c-4c65-4598-965a-dfda3de5d176/w_data[7]", ]

     walker_data <- walker_data[! walker_data$KEY == "86HOVQ1IOYA17F6H8RRHDFUGL/w_data[5]", ]
     ############################################################
     #############                                   ############
     ###########                                       ##########
     ########     E N D                                  ########
     ####          P A N O R M O S #REMOTE#WEEK              ####
     ########                            2 0 2 0         ########
     ###########                                       ##########
     #############                                   ############
     ############################################################

#Different remarks
# -  Currently no ODK data for 3298, walker line nos. guessed based on earlier
#   and later tracts;
#
#  - Tr 5058 -- data apparently not recorded, check walker paper record for w001s
#
# - Tr 5068 may have been skipped accidentally ??? --> no action

## All tracts with id nos. under 1000 should be removed from analysis as
## they are training tracts.
  walker_data <- walker_data[walker_data$w_tract_no >= 1000, ]


# Order walker_data
walker_data <- walker_data[order(walker_data$w_tract_no,
                                 walker_data$w_position), ]
rownames(walker_data) <- 1:nrow(walker_data)

# Change variable names with file description
  walker_data <- subset(walker_data,
                       select = as.character(description_tract_walker_data$ODKExportName))
  colnames(walker_data) <- description_tract_walker_data$Variable
  walker_data <- walker_data[!is.na(colnames(walker_data))]
  walker_data[is.na(walker_data)] <- ""

# Compare walker data with canonical if they exist
# Read canonical data and make them similar to walker data
walker_data_initial_path <- paste(wd_survey,tract_folder_canonical,
                                  "Tract_walker_data.csv", sep = "")

if (file.exists(walker_data_initial_path)){

  walker_data_test <- walker_data

  for (i in 1:ncol(walker_data_test)) {
    if (is.factor(walker_data_test[,i]) == TRUE) {
      walker_data_test[,i] <- as.character(walker_data_test[,i])
    } else
    if (is.numeric(walker_data_test[,i]) == TRUE) {
      walker_data_test[,i] <- as.integer(walker_data_test[,i])
    }
  }

  walker_data_initial <-  read.csv(walker_data_initial_path,
                                   stringsAsFactors = FALSE)

  # Test for similarity
  test_diff <- identical(walker_data_test, walker_data_initial)
  rm(walker_data_test, walker_data_initial)

  # Exporting data if needed and user say Y
  if(test_diff == FALSE){
    while(test_diff!= "Y" | test_diff !="N") {
      cat("\n \n The 'Tract_walker_data' have been changed and")
      cat("\n the canonical version will be updated.")
      cat("\n Do you agree [Y/N]? ")
      cat("\n (use a capital letter)   :")
      test_diff  <- readChar("stdin", 1)
      if(test_diff == "Y"){
        write.csv(walker_data,
                  file = paste(wd_survey,tract_folder_canonical,
                               "Tract_walker_data.csv", sep = ""),
                  row.names = FALSE)
        cat("\n Canonical data have been overwritten\n \n")
        break}  # breaks when hit enter
      if(test_diff == "N"){
        cat("\n Canonical data have NOT been overwritten\n \n")
        break}  # breaks when hit enter
    }
  } else
    cat("\n walker_data are already identical to canonical data \n  ")
}
if (!file.exists(walker_data_initial_path)){
  write.csv(walker_data,
            file = paste(wd_survey,tract_folder_canonical,
                         "Tract_walker_data.csv", sep = ""),
            row.names = FALSE)
  cat("\n a file tract_data.csv has been added in the folder canonical \n \n ")
}
