#!/usr/bin/Rscript --vanilla

#--------------------------------------------------------------------------------
# Aim: Transform finds.csv data on a per year basis into a Turkish translation, 
# suitable for inclusion in the report
# Code: Toby C. Wilkinson
# Last modified: 2017-09-16
# Licence: CC BY 4.0
#--------------------------------------------------------------------------------

library(plyr)
library(stringr)

wd_survey <- "../../survey-data/"
export_dir <- "../../"

year <- readline(prompt="Enter year to generate for: ")

if(!(year %in% c("2015","2017","2019"))) { year<-"2019" }

rejig <- function(source,target,year) {
  ### Load Finds data
  find_data <- read.csv(source, encoding = "UTF-8")
  
  # FindCode	ItemCode	Type	POINo	TractNo	WalkerNo	SherdType	VesselType
  # VesselComparanda	Fabric	FabricComparanda	DatingStart	DatingEnd	ProvisionalDating	Storage
  
  # Select only required columns
  etudluk <- subset(find_data, select=c("FindCode","POINo","TractNo","SherdType","ProvisionalDating","Type","VesselType","Fabric"))

  #Rename columns
  etudluk <- rename(etudluk, c("FindCode" = "BuluntuNo","ProvisionalDating" = "Date"))
    
  #Translate terms
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Rim", "Ağız")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Base", "Dip")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Foot", "Dip")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Standring", "Dip")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Toe", "Dip")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Flat", "düz")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Lid", "Kapak")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Handle", "Kulp")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Body", "Gövde")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Neck", "Boğaz")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i)Spout", "Akıtacak")
  etudluk$SherdType <- ifelse(etudluk$SherdType=="","Belirsiz şekil",etudluk$SherdType)
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i) and ", " ve ")
  etudluk$SherdType <- str_replace_all(etudluk$SherdType, "(?i) or ", " veya ")
  
  # Date-related replaces
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Late antique", "Geç Roma")  
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Byzantine", "Bizans")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Ottoman", "Osman")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Iron Age", "Demir Çağı")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Roman", "Roma")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)empire", "İmparatorluğu")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Archaic", "Arkaik")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Classical", "Klasik")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Geometric", "Geometrik")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Hellenistic", "Hellenistik")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Bronze Age", "Tunç Çağı")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Neolithic", "Neolitik")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)EBA", "Erken Tunç Çağı")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)LM", "Son Tunç/LM")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Geometric", "Geometrik")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Chalcolithic", "Kalkolitik")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Modern", "Modern") 
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)neuzeitlich", "Modern") 
  
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Early", "Erken")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Middle", "Orta")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i)Late", "Geç")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i) and ", " ve ")
  etudluk$Date <- str_replace_all(etudluk$Date, "(?i) or ", " veya ")
  
  etudluk$Date <- ifelse(etudluk$Date=="","Belirsiz dönem",etudluk$Date)
  
  # Other Material and Lithic-related replaces
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Lithic", "Litik")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Obsidian", "Litik (Obsidiyen)")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Marble", "Mermer")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Glas", "Cam")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Chert", "Litik (Çört)")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Stone", "Taş")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Ceramic", "Seramik")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Iron", "Demir")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Metal", "Metal")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)Hornfels", "Taş (hornfels)")
  etudluk$Fabric <- str_replace_all(etudluk$Fabric, "(?i)H[a]?ematite", "Hematit")
  
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Blade", "Dilgi")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Flake", "Yonga")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Tool", "Alet")
  # find translations for: e.g., Lamp, Glass or Glas, hammer, grinder, architectural, ore (maden), slag (cüruf)
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)e.g.", "")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i) and ", " ve ") 
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i) or ", " veya ") 
  
  # Other form replacement fields
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Lamp", "Lamba")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Weight", "Ağırlık")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Arrowhead", "Ok")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Knife", "Bıçak")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Axe", "Balta")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Millstone", "Değirmentaşı")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Grindstone", "Ezgitaşı")

  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Seashell", "Deniz kabuğu")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Fossil", "Fosil")
  etudluk$VesselType <- str_replace_all(etudluk$VesselType, "(?i)Geological sample", "Geolojik örnek")
    
  #Create synthetic columns
  etudluk$KontekstNo <- ifelse(
    etudluk$TractNo=="" | is.na(etudluk$TractNo),
    ifelse(etudluk$POINo=="" | is.na(etudluk$POINo),
           "!!Context not recognised!!",
           paste("POI ", etudluk$POINo)
           ),
    paste("Tr. ",etudluk$TractNo))
  etudluk$İçerik <- ifelse(etudluk$Type=="K",
    paste("Amorf seramik: ",etudluk$SherdType, " parçası, ",etudluk$Date,sep=""),
    ifelse(etudluk$Type=="L",
           paste(etudluk$Fabric,": ",etudluk$VesselType, ", ",etudluk$Date,sep=""),
           ifelse(etudluk$Type=="SF",
                  paste("Küçük buluntu: ", etudluk$Fabric," ",etudluk$VesselType, ", ",etudluk$Date,sep=""),
                  ifelse(etudluk$Type=="F",
                         paste("Fossil",sep=""),
                         paste("Diğer buluntu: ", etudluk$Fabric," ",etudluk$VesselType, ", ",etudluk$Date,sep="")
                  )
           )
           )
    )
  etudluk$TorbaNo <- paste0(year,"/")
  etudluk$BuluntuNo <- paste(etudluk$BuluntuNo," (",etudluk$Type,")",sep="")
  
  #Select desired columns only
  etudluk <- subset(etudluk, select=c("TorbaNo","BuluntuNo","KontekstNo","İçerik"))
  
  write.csv(etudluk, target, row.names=FALSE, fileEncoding="UTF-8")
}


## Generate list for 2017
finds_save_name <- paste0("finds",year,"etudluk.csv")
rejig(paste(wd_survey, "find-data/",year,"/","finds",year,".csv", sep = ""),paste(export_dir,finds_save_name, sep = ""),year)
message(paste0("Written to ",export_dir,finds_save_name))

