#!/usr/bin/Rscript --vanilla

#-------------------------------------------------------------------------------
# Aim: redact spatial data from all POI*.csv files to facilitate easier 
#        public and open CI artifact creation of survey datasets 
#        (NORMALLY NOT FOR COMMITING TO GIT HISTORY)
# Author (aut): Toby Wilkinson (based on scripts by Néhémie Strupler)
# Maintainer (cre): Toby Wilkinson
# Last modified: 2017-08-19
# Licence: CC BY-SA 4.0
#-------------------------------------------------------------------------------

### Set redaction options: 
# redacted_message is added as an additional field to all files
# redacted_content can be blank or simplified as to provide a notional data amount but not reasonable
# A more sophisticated redaction of spatial data could take original coordinate and randomize it.
redacted_message <- "SPATIAL LOCATION HAS BEEN REDACTED BUT IS AVAILABLE ON REQUEST (data.request@panormos.de)"
redacted_contentLat <- 37
redacted_contentLong <- 27

# Load the data 
## Define fixed variable

wd_survey <- c("../../survey-data/")
poi_folder <- c("poi-data/")
poi_folder_odk <- paste0(poi_folder, "export_odk/")
poi_folder_canonical <- paste0(poi_folder, "canonical/")
poi_r1  <- "POI_r1/POI.csv" 
poi_r2  <- "POI_r2/POI.csv" 
poi_r3  <- "POI_r3/POI.csv" 
poi_r4  <- "POI_r4/POI_r4.csv" 
poi_r6  <- "POI_r6/POI_r6.csv" 
poi_r7  <- "POI_r7/POI_r7.csv" 
poi_canonical <- "POI_data.csv"
# Swap to write seperate file or overwrite originals: USE WITH CARE
#suffix <- "_redact.csv"
suffix <- ""

description_poi_data_path <- paste0(wd_survey, poi_folder, 
                                     "description_canonical_poi-data.csv")

### Load the poi data
poi_data_r1 <- 
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r1), encoding = "UTF-8")
poi_data_r2 <- 
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r2), encoding = "UTF-8")
poi_data_r3 <- 
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r3), encoding = "UTF-8")
poi_data_r4 <- 
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r4), encoding = "UTF-8")
poi_data_r6 <- 
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r6), encoding = "UTF-8")
poi_data_r7 <- 
  read.csv(paste0(wd_survey, poi_folder_odk, poi_r7), encoding = "UTF-8")
poi_data_canonical <- 
  read.csv(paste0(wd_survey, poi_folder_canonical, poi_canonical), encoding = "UTF-8")

poi_data_canonical$`CentreLatitude` <- redacted_contentLat
poi_data_canonical$`CentreLongitude` <- redacted_contentLong
poi_data_canonical$`REDACTION_NOTE` <- redacted_message
write.csv(poi_data_canonical, 
          file = paste0(wd_survey, poi_folder_canonical, poi_canonical, suffix), 
          row.names = FALSE)

poi_data_r1$`basic_data.gis_point.Latitude` <- redacted_contentLat
poi_data_r1$`basic_data.gis_point.Longitude` <- redacted_contentLong
poi_data_r1$`REDACTION_NOTE` <- redacted_message
write.csv(poi_data_r1, 
          file = paste0(wd_survey, poi_folder_odk, poi_r1, suffix), 
          row.names = FALSE)

poi_data_r2$`basic_data.gis_point.Latitude` <- redacted_contentLat
poi_data_r2$`basic_data.gis_point.Longitude` <- redacted_contentLong
poi_data_r2$`REDACTION_NOTE` <- redacted_message
write.csv(poi_data_r2, 
          file = paste0(wd_survey, poi_folder_odk, poi_r2, suffix), 
          row.names = FALSE)

poi_data_r3$`basic_data.gis_point.Latitude` <- redacted_contentLat
poi_data_r3$`basic_data.gis_point.Longitude` <- redacted_contentLong
poi_data_r3$`REDACTION_NOTE` <- redacted_message
write.csv(poi_data_r3, 
          file = paste0(wd_survey, poi_folder_odk, poi_r3, suffix), 
          row.names = FALSE)

poi_data_r4$`basic_data.gis_point.Latitude` <- redacted_contentLat
poi_data_r4$`basic_data.gis_point.Longitude` <- redacted_contentLong
poi_data_r4$`REDACTION_NOTE` <- redacted_message
write.csv(poi_data_r4, 
          file = paste0(wd_survey, poi_folder_odk, poi_r4, suffix), 
          row.names = FALSE)

poi_data_r6$`basic_data.gis_point.Latitude` <- redacted_contentLat
poi_data_r6$`basic_data.gis_point.Longitude` <- redacted_contentLong
poi_data_r6$`REDACTION_NOTE` <- redacted_message
write.csv(poi_data_r6, 
          file = paste0(wd_survey, poi_folder_odk, poi_r6, suffix), 
          row.names = FALSE)

poi_data_r7$`basic_data.gis_point.Latitude` <- redacted_contentLat
poi_data_r7$`basic_data.gis_point.Longitude` <- redacted_contentLong
poi_data_r7$`REDACTION_NOTE` <- redacted_message
write.csv(poi_data_r7, 
          file = paste0(wd_survey, poi_folder_odk, poi_r7, suffix), 
          row.names = FALSE)

cat("\n Spatial data has been redacted from all POI files. \n Advise against committing redacted versions to git history to avoid confusion  \n \n ")
