#!/usr/bin/Rscript --vanilla

#-------------------------------------------------------------------------------
# Aim: redact name from all walker-data/*.csv files to facilitate easier
#        public and open CI artifact creation of survey datasets
#        (NORMALLY NOT FOR COMMITING TO GIT HISTORY)
# Author (aut): Toby Wilkinson
# Maintainer (cre): Toby Wilkinson
# Last modified: 2017-10-09
# Licence: CC BY-SA 4.0
#-------------------------------------------------------------------------------

### Set redaction options:
# redacted_message is added as an additional field to all files
# redacted_content can be blank or simplified as to provide a notional data amount but not reasonable
# A more sophisticated redaction of spatial data could take original coordinate and randomize it.
redacted_message <- "NAME DATA HAS BEEN REDACTED BUT MAY BE AVAILABLE ON REQUEST (technical@panormos.de)"
redacted_content <- "REDACTED"
redacted_contentInitials <- "xx"

# Load the data
## Define fixed variable

wd_survey <- c("../../survey-data/")
walkerdata_folder <- c("walker-data/")
walkerdata_canonical <- "walkers.csv"
# Swap to write seperate file or overwrite originals: USE WITH CARE
#suffix <- "_redact.csv"
suffix <- ""

### Load the poi data
walkerdata_data_canonical <-
  read.csv(paste0(wd_survey, walkerdata_folder, walkerdata_canonical), encoding = "UTF-8")

walkerdata_data_canonical$`WalkerName` <- redacted_content
walkerdata_data_canonical$`WalkerInitials` <- redacted_contentInitials
walkerdata_data_canonical$`ASCII` <- redacted_contentInitials

walkerdata_data_canonical$`REDACTION_NOTE` <- redacted_message

write.csv(walkerdata_data_canonical,
          file = paste0(wd_survey, walkerdata_folder, walkerdata_canonical, suffix),
          row.names = FALSE)

cat("\n Name data has been redacted from all walker-data files. \n Do not commit redacted versions to git history to avoid confusion  \n \n ")
